"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def deregister(hub, ctx, task_definition: str) -> Dict:
    r"""
    **Autogenerated function**

    Deregisters the specified task definition by family and revision. Upon deregistration, the task definition is marked as INACTIVE. Existing tasks and services that reference an INACTIVE task definition continue to run without disruption. Existing services that reference an INACTIVE task definition can still scale up or down by modifying the service's desired count. You cannot use an INACTIVE task definition to run new tasks or create new services, and you cannot update an existing service to reference an INACTIVE task definition. However, there may be up to a 10-minute window following deregistration where these restrictions have not yet taken effect.  At this time, INACTIVE task definitions remain discoverable in your account indefinitely. However, this behavior is subject to change in the future, so you should not rely on INACTIVE task definitions persisting beyond the lifecycle of any associated tasks and services.

    Args:
        task_definition(str): The family and revision (family:revision) or full Amazon Resource Name (ARN) of the task definition to deregister. You must specify a revision.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecs.task.definition.init.deregister(ctx, task_definition=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecs.task.definition.init.deregister task_definition=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecs",
        operation="deregister_task_definition",
        op_kwargs={"taskDefinition": task_definition},
    )


async def describe(hub, ctx, task_definition: str, include: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Describes a task definition. You can specify a family and revision to find information about a specific task definition, or you can simply specify the family to find the latest ACTIVE revision in that family.  You can only describe INACTIVE task definitions while an active task or service references them.

    Args:
        task_definition(str): The family for the latest ACTIVE revision, family and revision (family:revision) for a specific revision in the family, or full Amazon Resource Name (ARN) of the task definition to describe.
        include(List, optional): Specifies whether to see the resource tags for the task definition. If TAGS is specified, the tags are included in the response. If this field is omitted, tags are not included in the response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecs.task.definition.init.describe(ctx, task_definition=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecs.task.definition.init.describe task_definition=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecs",
        operation="describe_task_definition",
        op_kwargs={"taskDefinition": task_definition, "include": include},
    )


async def list_all(
    hub,
    ctx,
    family_prefix: str = None,
    status: str = None,
    sort: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of task definitions that are registered to your account. You can filter the results by family name with the familyPrefix parameter or by status with the status parameter.

    Args:
        family_prefix(str, optional): The full family name with which to filter the ListTaskDefinitions results. Specifying a familyPrefix limits the listed task definitions to task definition revisions that belong to that family. Defaults to None.
        status(str, optional): The task definition status with which to filter the ListTaskDefinitions results. By default, only ACTIVE task definitions are listed. By setting this parameter to INACTIVE, you can view task definitions that are INACTIVE as long as an active task or service still references them. If you paginate the resulting output, be sure to keep the status value constant in each subsequent request. Defaults to None.
        sort(str, optional): The order in which to sort the results. Valid values are ASC and DESC. By default (ASC), task definitions are listed lexicographically by family name and in ascending numerical order by revision so that the newest task definitions in a family are listed last. Setting this parameter to DESC reverses the sort order on family name and revision so that the newest task definitions in a family are listed first. Defaults to None.
        next_token(str, optional): The nextToken value returned from a ListTaskDefinitions request indicating that more results are available to fulfill the request and further calls will be needed. If maxResults was provided, it is possible the number of results to be fewer than maxResults.  This token should be treated as an opaque identifier that is only used to retrieve the next items in a list and not for other programmatic purposes. . Defaults to None.
        max_results(int, optional): The maximum number of task definition results returned by ListTaskDefinitions in paginated output. When this parameter is used, ListTaskDefinitions only returns maxResults results in a single page along with a nextToken response element. The remaining results of the initial request can be seen by sending another ListTaskDefinitions request with the returned nextToken value. This value can be between 1 and 100. If this parameter is not used, then ListTaskDefinitions returns up to 100 results and a nextToken value if applicable. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecs.task.definition.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecs.task.definition.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecs",
        operation="list_task_definitions",
        op_kwargs={
            "familyPrefix": family_prefix,
            "status": status,
            "sort": sort,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )


async def register(
    hub,
    ctx,
    family: str,
    container_definitions: List,
    task_role_arn: str = None,
    execution_role_arn: str = None,
    network_mode: str = None,
    volumes: List = None,
    placement_constraints: List = None,
    requires_compatibilities: List = None,
    cpu: str = None,
    memory: str = None,
    tags: List = None,
    pid_mode: str = None,
    ipc_mode: str = None,
    proxy_configuration: Dict = None,
    inference_accelerators: List = None,
    ephemeral_storage: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Registers a new task definition from the supplied family and containerDefinitions. Optionally, you can add data volumes to your containers with the volumes parameter. For more information about task definition parameters and defaults, see Amazon ECS Task Definitions in the Amazon Elastic Container Service Developer Guide. You can specify an IAM role for your task with the taskRoleArn parameter. When you specify an IAM role for a task, its containers can then use the latest versions of the CLI or SDKs to make API requests to the Amazon Web Services services that are specified in the IAM policy associated with the role. For more information, see IAM Roles for Tasks in the Amazon Elastic Container Service Developer Guide. You can specify a Docker networking mode for the containers in your task definition with the networkMode parameter. The available network modes correspond to those described in Network settings in the Docker run reference. If you specify the awsvpc network mode, the task is allocated an elastic network interface, and you must specify a NetworkConfiguration when you create a service or run a task with the task definition. For more information, see Task Networking in the Amazon Elastic Container Service Developer Guide.

    Args:
        family(str): You must specify a family for a task definition, which allows you to track multiple versions of the same task definition. The family is used as a name for your task definition. Up to 255 letters (uppercase and lowercase), numbers, underscores, and hyphens are allowed.
        task_role_arn(str, optional): The short name or full Amazon Resource Name (ARN) of the IAM role that containers in this task can assume. All containers in this task are granted the permissions that are specified in this role. For more information, see IAM Roles for Tasks in the Amazon Elastic Container Service Developer Guide. Defaults to None.
        execution_role_arn(str, optional): The Amazon Resource Name (ARN) of the task execution role that grants the Amazon ECS container agent permission to make Amazon Web Services API calls on your behalf. The task execution IAM role is required depending on the requirements of your task. For more information, see Amazon ECS task execution IAM role in the Amazon Elastic Container Service Developer Guide. Defaults to None.
        network_mode(str, optional): The Docker networking mode to use for the containers in the task. The valid values are none, bridge, awsvpc, and host. If no network mode is specified, the default is bridge. For Amazon ECS tasks on Fargate, the awsvpc network mode is required. For Amazon ECS tasks on Amazon EC2 Linux instances, any network mode can be used. For Amazon ECS tasks on Amazon EC2 Windows instances, <default> or awsvpc can be used. If the network mode is set to none, you cannot specify port mappings in your container definitions, and the tasks containers do not have external connectivity. The host and awsvpc network modes offer the highest networking performance for containers because they use the EC2 network stack instead of the virtualized network stack provided by the bridge mode. With the host and awsvpc network modes, exposed container ports are mapped directly to the corresponding host port (for the host network mode) or the attached elastic network interface port (for the awsvpc network mode), so you cannot take advantage of dynamic host port mappings.   When using the host network mode, you should not run containers using the root user (UID 0). It is considered best practice to use a non-root user.  If the network mode is awsvpc, the task is allocated an elastic network interface, and you must specify a NetworkConfiguration value when you create a service or run a task with the task definition. For more information, see Task Networking in the Amazon Elastic Container Service Developer Guide. If the network mode is host, you cannot run multiple instantiations of the same task on a single container instance when port mappings are used. For more information, see Network settings in the Docker run reference. Defaults to None.
        container_definitions(List): A list of container definitions in JSON format that describe the different containers that make up your task.
        volumes(List, optional): A list of volume definitions in JSON format that containers in your task may use. Defaults to None.
        placement_constraints(List, optional): An array of placement constraint objects to use for the task. You can specify a maximum of 10 constraints per task (this limit includes constraints in the task definition and those specified at runtime). Defaults to None.
        requires_compatibilities(List, optional): The task launch type that Amazon ECS should validate the task definition against. A client exception is returned if the task definition doesn't validate against the compatibilities specified. If no value is specified, the parameter is omitted from the response. Defaults to None.
        cpu(str, optional): The number of CPU units used by the task. It can be expressed as an integer using CPU units, for example 1024, or as a string using vCPUs, for example 1 vCPU or 1 vcpu, in a task definition. String values are converted to an integer indicating the CPU units when the task definition is registered.  Task-level CPU and memory parameters are ignored for Windows containers. We recommend specifying container-level resources for Windows containers.  If you are using the EC2 launch type, this field is optional. Supported values are between 128 CPU units (0.125 vCPUs) and 10240 CPU units (10 vCPUs). If you are using the Fargate launch type, this field is required and you must use one of the following values, which determines your range of supported values for the memory parameter:   256 (.25 vCPU) - Available memory values: 512 (0.5 GB), 1024 (1 GB), 2048 (2 GB)   512 (.5 vCPU) - Available memory values: 1024 (1 GB), 2048 (2 GB), 3072 (3 GB), 4096 (4 GB)   1024 (1 vCPU) - Available memory values: 2048 (2 GB), 3072 (3 GB), 4096 (4 GB), 5120 (5 GB), 6144 (6 GB), 7168 (7 GB), 8192 (8 GB)   2048 (2 vCPU) - Available memory values: Between 4096 (4 GB) and 16384 (16 GB) in increments of 1024 (1 GB)   4096 (4 vCPU) - Available memory values: Between 8192 (8 GB) and 30720 (30 GB) in increments of 1024 (1 GB)  . Defaults to None.
        memory(str, optional): The amount of memory (in MiB) used by the task. It can be expressed as an integer using MiB, for example 1024, or as a string using GB, for example 1GB or 1 GB, in a task definition. String values are converted to an integer indicating the MiB when the task definition is registered.  Task-level CPU and memory parameters are ignored for Windows containers. We recommend specifying container-level resources for Windows containers.  If using the EC2 launch type, this field is optional. If using the Fargate launch type, this field is required and you must use one of the following values, which determines your range of supported values for the cpu parameter:   512 (0.5 GB), 1024 (1 GB), 2048 (2 GB) - Available cpu values: 256 (.25 vCPU)   1024 (1 GB), 2048 (2 GB), 3072 (3 GB), 4096 (4 GB) - Available cpu values: 512 (.5 vCPU)   2048 (2 GB), 3072 (3 GB), 4096 (4 GB), 5120 (5 GB), 6144 (6 GB), 7168 (7 GB), 8192 (8 GB) - Available cpu values: 1024 (1 vCPU)   Between 4096 (4 GB) and 16384 (16 GB) in increments of 1024 (1 GB) - Available cpu values: 2048 (2 vCPU)   Between 8192 (8 GB) and 30720 (30 GB) in increments of 1024 (1 GB) - Available cpu values: 4096 (4 vCPU)  . Defaults to None.
        tags(List, optional): The metadata that you apply to the task definition to help you categorize and organize them. Each tag consists of a key and an optional value, both of which you define. The following basic restrictions apply to tags:   Maximum number of tags per resource - 50   For each resource, each tag key must be unique, and each tag key can have only one value.   Maximum key length - 128 Unicode characters in UTF-8   Maximum value length - 256 Unicode characters in UTF-8   If your tagging schema is used across multiple services and resources, remember that other services may have restrictions on allowed characters. Generally allowed characters are: letters, numbers, and spaces representable in UTF-8, and the following characters: + - = . _ : / @.   Tag keys and values are case-sensitive.   Do not use aws:, AWS:, or any upper or lowercase combination of such as a prefix for either keys or values as it is reserved for Amazon Web Services use. You cannot edit or delete tag keys or values with this prefix. Tags with this prefix do not count against your tags per resource limit.  . Defaults to None.
        pid_mode(str, optional): The process namespace to use for the containers in the task. The valid values are host or task. If host is specified, then all containers within the tasks that specified the host PID mode on the same container instance share the same process namespace with the host Amazon EC2 instance. If task is specified, all containers within the specified task share the same process namespace. If no value is specified, the default is a private namespace. For more information, see PID settings in the Docker run reference. If the host PID mode is used, be aware that there is a heightened risk of undesired process namespace expose. For more information, see Docker security.  This parameter is not supported for Windows containers or tasks run on Fargate. . Defaults to None.
        ipc_mode(str, optional): The IPC resource namespace to use for the containers in the task. The valid values are host, task, or none. If host is specified, then all containers within the tasks that specified the host IPC mode on the same container instance share the same IPC resources with the host Amazon EC2 instance. If task is specified, all containers within the specified task share the same IPC resources. If none is specified, then IPC resources within the containers of a task are private and not shared with other containers in a task or on the container instance. If no value is specified, then the IPC resource namespace sharing depends on the Docker daemon setting on the container instance. For more information, see IPC settings in the Docker run reference. If the host IPC mode is used, be aware that there is a heightened risk of undesired IPC namespace expose. For more information, see Docker security. If you are setting namespaced kernel parameters using systemControls for the containers in the task, the following will apply to your IPC resource namespace. For more information, see System Controls in the Amazon Elastic Container Service Developer Guide.   For tasks that use the host IPC mode, IPC namespace related systemControls are not supported.   For tasks that use the task IPC mode, IPC namespace related systemControls will apply to all containers within a task.    This parameter is not supported for Windows containers or tasks run on Fargate. . Defaults to None.
        proxy_configuration(Dict, optional): The configuration details for the App Mesh proxy. For tasks hosted on Amazon EC2 instances, the container instances require at least version 1.26.0 of the container agent and at least version 1.26.0-1 of the ecs-init package to enable a proxy configuration. If your container instances are launched from the Amazon ECS-optimized AMI version 20190301 or later, then they contain the required versions of the container agent and ecs-init. For more information, see Amazon ECS-optimized AMI versions in the Amazon Elastic Container Service Developer Guide. Defaults to None.
        inference_accelerators(List, optional): The Elastic Inference accelerators to use for the containers in the task. Defaults to None.
        ephemeral_storage(Dict, optional): The amount of ephemeral storage to allocate for the task. This parameter is used to expand the total amount of ephemeral storage available, beyond the default amount, for tasks hosted on Fargate. For more information, see Fargate task storage in the Amazon ECS User Guide for Fargate.  This parameter is only supported for tasks hosted on Fargate using platform version 1.4.0 or later. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecs.task.definition.init.register(
                ctx, family=value, container_definitions=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecs.task.definition.init.register family=value, container_definitions=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecs",
        operation="register_task_definition",
        op_kwargs={
            "family": family,
            "taskRoleArn": task_role_arn,
            "executionRoleArn": execution_role_arn,
            "networkMode": network_mode,
            "containerDefinitions": container_definitions,
            "volumes": volumes,
            "placementConstraints": placement_constraints,
            "requiresCompatibilities": requires_compatibilities,
            "cpu": cpu,
            "memory": memory,
            "tags": tags,
            "pidMode": pid_mode,
            "ipcMode": ipc_mode,
            "proxyConfiguration": proxy_configuration,
            "inferenceAccelerators": inference_accelerators,
            "ephemeralStorage": ephemeral_storage,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def cancel(hub, ctx, query_id: str) -> Dict:
    r"""
    **Autogenerated function**

     Cancels a query that has been issued. Cancellation is guaranteed only if the query has not completed execution before the cancellation request was issued. Because cancellation is an idempotent operation, subsequent cancellation requests will return a CancellationMessage, indicating that the query has already been canceled.

    Args:
        query_id(str):  The id of the query that needs to be cancelled. QueryID is returned as part of QueryResult. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.timestream_query.query.cancel(ctx, query_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.timestream_query.query.cancel query_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="timestream-query",
        operation="cancel_query",
        op_kwargs={"QueryId": query_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def tag(hub, ctx, arn: str, tags: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Associates a set of provided tags with a notification rule.

    Args:
        arn(str): The Amazon Resource Name (ARN) of the notification rule to tag.
        tags(Dict): The list of tags to associate with the resource. Tag key names cannot start with "aws".

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codestar_notification.resource.tag(ctx, arn=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codestar_notification.resource.tag arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codestar-notifications",
        operation="tag_resource",
        op_kwargs={"Arn": arn, "Tags": tags},
    )


async def untag(hub, ctx, arn: str, tag_keys: List) -> Dict:
    r"""
    **Autogenerated function**

    Removes the association between one or more provided tags and a notification rule.

    Args:
        arn(str): The Amazon Resource Name (ARN) of the notification rule from which to remove the tags.
        tag_keys(List): The key names of the tags to remove.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codestar_notification.resource.untag(
                ctx, arn=value, tag_keys=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codestar_notification.resource.untag arn=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codestar-notifications",
        operation="untag_resource",
        op_kwargs={"Arn": arn, "TagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Returns the bundles that can be applied to your Amazon Lightsail content delivery network (CDN) distributions. A distribution bundle specifies the monthly network transfer quota and monthly cost of your dsitribution.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.distribution.bundle.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.distribution.bundle.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="get_distribution_bundles",
        op_kwargs={},
    )


async def update(
    hub, ctx, distribution_name: str = None, bundle_id: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the bundle of your Amazon Lightsail content delivery network (CDN) distribution. A distribution bundle specifies the monthly network transfer quota and monthly cost of your dsitribution. Update your distribution's bundle if your distribution is going over its monthly network transfer quota and is incurring an overage fee. You can update your distribution's bundle only one time within your monthly AWS billing cycle. To determine if you can update your distribution's bundle, use the GetDistributions action. The ableToUpdateBundle parameter in the result will indicate whether you can currently update your distribution's bundle.

    Args:
        distribution_name(str, optional): The name of the distribution for which to update the bundle. Use the GetDistributions action to get a list of distribution names that you can specify. Defaults to None.
        bundle_id(str, optional): The bundle ID of the new bundle to apply to your distribution. Use the GetDistributionBundles action to get a list of distribution bundle IDs that you can specify. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.distribution.bundle.update(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.distribution.bundle.update
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="update_distribution_bundle",
        op_kwargs={"distributionName": distribution_name, "bundleId": bundle_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub,
    ctx,
    organization_id: str,
    resource_id: str,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the delegates associated with a resource. Users and groups can be resource delegates and answer requests on behalf of the resource.

    Args:
        organization_id(str): The identifier for the organization that contains the resource for which delegates are listed.
        resource_id(str): The identifier for the resource whose delegates are listed.
        next_token(str, optional): The token used to paginate through the delegates associated with a resource. Defaults to None.
        max_results(int, optional): The number of maximum results in a page. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workmail.resource.delegate.list_all(
                ctx, organization_id=value, resource_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workmail.resource.delegate.list_all organization_id=value, resource_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workmail",
        operation="list_resource_delegates",
        op_kwargs={
            "OrganizationId": organization_id,
            "ResourceId": resource_id,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(hub, ctx, page_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns the list of bundles that are available in Amazon Lightsail. A bundle describes the performance specifications for a database. You can use a bundle ID to create a new database with explicit performance specifications.

    Args:
        page_token(str, optional): The token to advance to the next page of results from your request. To get a page token, perform an initial GetRelationalDatabaseBundles request. If your results are paginated, the response will return a next page token that you can specify as the page token in a subsequent request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.relational_database.bundle.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.relational_database.bundle.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="get_relational_database_bundles",
        op_kwargs={"pageToken": page_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(hub, ctx, text_list: List, language_code: str) -> Dict:
    r"""
    **Autogenerated function**

    Inspects the text of a batch of documents for named entities and returns information about them. For more information about named entities, see how-entities

    Args:
        text_list(List): A list containing the text of the input documents. The list can contain a maximum of 25 documents. Each document must contain fewer than 5,000 bytes of UTF-8 encoded characters.
        language_code(str): The language of the input documents. You can specify any of the primary languages supported by Amazon Comprehend. All documents must be in the same language.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.comprehend.detect.entity.batch(
                ctx, text_list=value, language_code=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.comprehend.detect.entity.batch text_list=value, language_code=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="comprehend",
        operation="batch_detect_entities",
        op_kwargs={"TextList": text_list, "LanguageCode": language_code},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(hub, ctx, layer_name: str, version_number: int) -> None:
    r"""
    **Autogenerated function**

    Deletes a version of an Lambda layer. Deleted versions can no longer be viewed or added to functions. To avoid breaking functions, a copy of the version remains in Lambda until no functions refer to it.

    Args:
        layer_name(str): The name or Amazon Resource Name (ARN) of the layer.
        version_number(int): The version number.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lambda_.layer.version.init.delete(
                ctx, layer_name=value, version_number=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lambda_.layer.version.init.delete layer_name=value, version_number=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lambda",
        operation="delete_layer_version",
        op_kwargs={"LayerName": layer_name, "VersionNumber": version_number},
    )


async def get(hub, ctx, layer_name: str, version_number: int) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about a version of an Lambda layer, with a link to download the layer archive that's valid for 10 minutes.

    Args:
        layer_name(str): The name or Amazon Resource Name (ARN) of the layer.
        version_number(int): The version number.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lambda_.layer.version.init.get(
                ctx, layer_name=value, version_number=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lambda_.layer.version.init.get layer_name=value, version_number=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lambda",
        operation="get_layer_version",
        op_kwargs={"LayerName": layer_name, "VersionNumber": version_number},
    )


async def list_all(
    hub,
    ctx,
    layer_name: str,
    compatible_runtime: str = None,
    marker: str = None,
    max_items: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the versions of an Lambda layer. Versions that have been deleted aren't listed. Specify a runtime identifier to list only versions that indicate that they're compatible with that runtime.

    Args:
        compatible_runtime(str, optional): A runtime identifier. For example, go1.x. Defaults to None.
        layer_name(str): The name or Amazon Resource Name (ARN) of the layer.
        marker(str, optional): A pagination token returned by a previous call. Defaults to None.
        max_items(int, optional): The maximum number of versions to return. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lambda_.layer.version.init.list_all(ctx, layer_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lambda_.layer.version.init.list_all layer_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lambda",
        operation="list_layer_versions",
        op_kwargs={
            "CompatibleRuntime": compatible_runtime,
            "LayerName": layer_name,
            "Marker": marker,
            "MaxItems": max_items,
        },
    )


async def publish(
    hub,
    ctx,
    layer_name: str,
    content: Dict,
    description: str = None,
    compatible_runtimes: List = None,
    license_info: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an Lambda layer from a ZIP archive. Each time you call PublishLayerVersion with the same layer name, a new version is created. Add layers to your function with CreateFunction or UpdateFunctionConfiguration.

    Args:
        layer_name(str): The name or Amazon Resource Name (ARN) of the layer.
        description(str, optional): The description of the version. Defaults to None.
        content(Dict): The function layer archive.
        compatible_runtimes(List, optional): A list of compatible function runtimes. Used for filtering with ListLayers and ListLayerVersions. Defaults to None.
        license_info(str, optional): The layer's software license. It can be any of the following:   An SPDX license identifier. For example, MIT.   The URL of a license hosted on the internet. For example, https://opensource.org/licenses/MIT.   The full text of the license.  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lambda_.layer.version.init.publish(
                ctx, layer_name=value, content=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lambda_.layer.version.init.publish layer_name=value, content=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lambda",
        operation="publish_layer_version",
        op_kwargs={
            "LayerName": layer_name,
            "Description": description,
            "Content": content,
            "CompatibleRuntimes": compatible_runtimes,
            "LicenseInfo": license_info,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, key_id: str, policy_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets a key policy attached to the specified customer master key (CMK).  Cross-account use: No. You cannot perform this operation on a CMK in a different AWS account.  Required permissions: kms:GetKeyPolicy (key policy)  Related operations: PutKeyPolicy

    Args:
        key_id(str): Gets the key policy for the specified customer master key (CMK). Specify the key ID or key ARN of the CMK. For example:   Key ID: 1234abcd-12ab-34cd-56ef-1234567890ab    Key ARN: arn:aws:kms:us-east-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab    To get the key ID and key ARN for a CMK, use ListKeys or DescribeKey.
        policy_name(str): Specifies the name of the key policy. The only valid name is default. To get the names of key policies, use ListKeyPolicies.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kms.key.policy.get(ctx, key_id=value, policy_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kms.key.policy.get key_id=value, policy_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kms",
        operation="get_key_policy",
        op_kwargs={"KeyId": key_id, "PolicyName": policy_name},
    )


async def list_all(
    hub, ctx, key_id: str, limit: int = None, marker: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets the names of the key policies that are attached to a customer master key (CMK). This operation is designed to get policy names that you can use in a GetKeyPolicy operation. However, the only valid policy name is default.   Cross-account use: No. You cannot perform this operation on a CMK in a different AWS account.  Required permissions: kms:ListKeyPolicies (key policy)  Related operations:     GetKeyPolicy     PutKeyPolicy

    Args:
        key_id(str): Gets the names of key policies for the specified customer master key (CMK). Specify the key ID or key ARN of the CMK. For example:   Key ID: 1234abcd-12ab-34cd-56ef-1234567890ab    Key ARN: arn:aws:kms:us-east-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab    To get the key ID and key ARN for a CMK, use ListKeys or DescribeKey.
        limit(int, optional): Use this parameter to specify the maximum number of items to return. When this value is present, AWS KMS does not return more than the specified number of items, but it might return fewer. This value is optional. If you include a value, it must be between 1 and 1000, inclusive. If you do not include a value, it defaults to 100. Only one policy can be attached to a key. Defaults to None.
        marker(str, optional): Use this parameter in a subsequent request after you receive a response with truncated results. Set it to the value of NextMarker from the truncated response you just received. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kms.key.policy.list_all(ctx, key_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kms.key.policy.list_all key_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kms",
        operation="list_key_policies",
        op_kwargs={"KeyId": key_id, "Limit": limit, "Marker": marker},
    )


async def put(
    hub,
    ctx,
    key_id: str,
    policy_name: str,
    policy: str,
    bypass_policy_lockout_safety_check: bool = None,
) -> None:
    r"""
    **Autogenerated function**

    Attaches a key policy to the specified customer master key (CMK).  For more information about key policies, see Key Policies in the AWS Key Management Service Developer Guide. For help writing and formatting a JSON policy document, see the IAM JSON Policy Reference in the  IAM User Guide . For examples of adding a key policy in multiple programming languages, see Setting a key policy in the AWS Key Management Service Developer Guide.  Cross-account use: No. You cannot perform this operation on a CMK in a different AWS account.  Required permissions: kms:PutKeyPolicy (key policy)  Related operations: GetKeyPolicy

    Args:
        key_id(str): Sets the key policy on the specified customer master key (CMK). Specify the key ID or key ARN of the CMK. For example:   Key ID: 1234abcd-12ab-34cd-56ef-1234567890ab    Key ARN: arn:aws:kms:us-east-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab    To get the key ID and key ARN for a CMK, use ListKeys or DescribeKey.
        policy_name(str): The name of the key policy. The only valid value is default.
        policy(str): The key policy to attach to the CMK. The key policy must meet the following criteria:   If you don't set BypassPolicyLockoutSafetyCheck to true, the key policy must allow the principal that is making the PutKeyPolicy request to make a subsequent PutKeyPolicy request on the CMK. This reduces the risk that the CMK becomes unmanageable. For more information, refer to the scenario in the Default Key Policy section of the AWS Key Management Service Developer Guide.   Each statement in the key policy must contain one or more principals. The principals in the key policy must exist and be visible to AWS KMS. When you create a new AWS principal (for example, an IAM user or role), you might need to enforce a delay before including the new principal in a key policy because the new principal might not be immediately visible to AWS KMS. For more information, see Changes that I make are not always immediately visible in the AWS Identity and Access Management User Guide.   The key policy cannot exceed 32 kilobytes (32768 bytes). For more information, see Resource Quotas in the AWS Key Management Service Developer Guide.
        bypass_policy_lockout_safety_check(bool, optional): A flag to indicate whether to bypass the key policy lockout safety check.  Setting this value to true increases the risk that the CMK becomes unmanageable. Do not set this value to true indiscriminately. For more information, refer to the scenario in the Default Key Policy section in the AWS Key Management Service Developer Guide.  Use this parameter only when you intend to prevent the principal that is making the request from making a subsequent PutKeyPolicy request on the CMK. The default value is false. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kms.key.policy.put(
                ctx, key_id=value, policy_name=value, policy=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kms.key.policy.put key_id=value, policy_name=value, policy=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kms",
        operation="put_key_policy",
        op_kwargs={
            "KeyId": key_id,
            "PolicyName": policy_name,
            "Policy": policy,
            "BypassPolicyLockoutSafetyCheck": bypass_policy_lockout_safety_check,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def associate(
    hub, ctx, sidewalk: Dict, client_request_token: str = None, tags: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Associates a partner account with your AWS account.

    Args:
        sidewalk(Dict): The Sidewalk account credentials.
        client_request_token(str, optional): Each resource must have a unique client request token. If you try to create a new resource with the same token as a resource that already exists, an exception occurs. If you omit this value, AWS SDKs will automatically generate a unique client request. . Defaults to None.
        tags(List, optional): The tags to attach to the specified resource. Tags are metadata that you can use to manage a resource. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotwireless.aws_account.with_partner_account.associate(
                ctx, sidewalk=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotwireless.aws_account.with_partner_account.associate sidewalk=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotwireless",
        operation="associate_aws_account_with_partner_account",
        op_kwargs={
            "Sidewalk": sidewalk,
            "ClientRequestToken": client_request_token,
            "Tags": tags,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def remove(
    hub, ctx, global_cluster_identifier: str = None, db_cluster_identifier: str = None
) -> Dict:
    r"""
    **Autogenerated function**

     Detaches an Aurora secondary cluster from an Aurora global database cluster. The cluster becomes a standalone cluster with read-write capability instead of being read-only and receiving data from a primary cluster in a different region.   This action only applies to Aurora DB clusters.

    Args:
        global_cluster_identifier(str, optional):  The cluster identifier to detach from the Aurora global database cluster. . Defaults to None.
        db_cluster_identifier(str, optional):  The Amazon Resource Name (ARN) identifying the cluster that was detached from the Aurora global database cluster. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.from_global_cluster.remove(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.from_global_cluster.remove
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="remove_from_global_cluster",
        op_kwargs={
            "GlobalClusterIdentifier": global_cluster_identifier,
            "DbClusterIdentifier": db_cluster_identifier,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def check(hub, ctx, cname_prefix: str) -> Dict:
    r"""
    **Autogenerated function**

    Checks if the specified CNAME is available.

    Args:
        cname_prefix(str): The prefix used when this CNAME is reserved.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticbeanstalk.dns_availability.check(ctx, cname_prefix=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticbeanstalk.dns_availability.check cname_prefix=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticbeanstalk",
        operation="check_dns_availability",
        op_kwargs={"CNAMEPrefix": cname_prefix},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub,
    ctx,
    resource_arn: str,
    catalog_id: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the Lake Formation permissions for a specified table or database resource located at a path in Amazon S3. GetEffectivePermissionsForPath will not return databases and tables if the catalog is encrypted.

    Args:
        catalog_id(str, optional): The identifier for the Data Catalog. By default, the account ID. The Data Catalog is the persistent metadata store. It contains database definitions, table definitions, and other control information to manage your AWS Lake Formation environment. . Defaults to None.
        resource_arn(str): The Amazon Resource Name (ARN) of the resource for which you want to get permissions.
        next_token(str, optional): A continuation token, if this is not the first call to retrieve this list. Defaults to None.
        max_results(int, optional): The maximum number of results to return. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lakeformation.effective_permission_for_path.get(
                ctx, resource_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lakeformation.effective_permission_for_path.get resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lakeformation",
        operation="get_effective_permissions_for_path",
        op_kwargs={
            "CatalogId": catalog_id,
            "ResourceArn": resource_arn,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(hub, ctx, event_arns: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns the number of entities that are affected by each of the specified events. If no events are specified, the counts of all affected entities are returned.

    Args:
        event_arns(List, optional): A list of event ARNs (unique identifiers). For example: "arn:aws:health:us-east-1::event/EC2/EC2_INSTANCE_RETIREMENT_SCHEDULED/EC2_INSTANCE_RETIREMENT_SCHEDULED_ABC123-CDE456", "arn:aws:health:us-west-1::event/EBS/AWS_EBS_LOST_VOLUME/AWS_EBS_LOST_VOLUME_CHI789_JKL101" . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.health.entity_aggregate.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.health.entity_aggregate.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="health",
        operation="describe_entity_aggregates",
        op_kwargs={"eventArns": event_arns},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(
    hub, ctx, target_address: str, force_unsubscribe_all: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a specified target for notifications.

    Args:
        target_address(str): The Amazon Resource Name (ARN) of the SNS topic to delete.
        force_unsubscribe_all(bool, optional): A Boolean value that can be used to delete all associations with this SNS topic. The default value is FALSE. If set to TRUE, all associations between that target and every notification rule in your AWS account are deleted. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codestar_notification.target.delete(ctx, target_address=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codestar_notification.target.delete target_address=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codestar-notifications",
        operation="delete_target",
        op_kwargs={
            "TargetAddress": target_address,
            "ForceUnsubscribeAll": force_unsubscribe_all,
        },
    )


async def list_all(
    hub, ctx, filters: List = None, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of the notification rule targets for an AWS account.

    Args:
        filters(List, optional): The filters to use to return information by service or resource type. Valid filters include target type, target address, and target status.  A filter with the same name can appear more than once when used with OR statements. Filters with different names should be applied with AND statements. . Defaults to None.
        next_token(str, optional): An enumeration token that, when provided in a request, returns the next batch of the results. Defaults to None.
        max_results(int, optional): A non-negative integer used to limit the number of returned results. The maximum number of results that can be returned is 100. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codestar_notification.target.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codestar_notification.target.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codestar-notifications",
        operation="list_targets",
        op_kwargs={
            "Filters": filters,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(hub, ctx, solution_version_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets the metrics for the specified solution version.

    Args:
        solution_version_arn(str): The Amazon Resource Name (ARN) of the solution version for which to get metrics.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.personalize.solution.metric.get_all(
                ctx, solution_version_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.personalize.solution.metric.get_all solution_version_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="personalize",
        operation="get_solution_metrics",
        op_kwargs={"solutionVersionArn": solution_version_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__virtualname__ = "metric_filter"


async def delete(hub, ctx, log_group_name: str, filter_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified metric filter.

    Args:
        log_group_name(str): The name of the log group.
        filter_name(str): The name of the metric filter.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.logs.metric_filter_.delete(
                ctx, log_group_name=value, filter_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.logs.metric_filter.delete log_group_name=value, filter_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="logs",
        operation="delete_metric_filter",
        op_kwargs={"logGroupName": log_group_name, "filterName": filter_name},
    )


async def describe_all(
    hub,
    ctx,
    log_group_name: str = None,
    filter_name_prefix: str = None,
    next_token: str = None,
    limit: int = None,
    metric_name: str = None,
    metric_namespace: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the specified metric filters. You can list all of the metric filters or filter the results by log name, prefix, metric name, or metric namespace. The results are ASCII-sorted by filter name.

    Args:
        log_group_name(str, optional): The name of the log group. Defaults to None.
        filter_name_prefix(str, optional): The prefix to match. CloudWatch Logs uses the value you set here only if you also include the logGroupName parameter in your request. Defaults to None.
        next_token(str, optional): The token for the next set of items to return. (You received this token from a previous call.). Defaults to None.
        limit(int, optional): The maximum number of items returned. If you don't specify a value, the default is up to 50 items. Defaults to None.
        metric_name(str, optional): Filters results to include only those with the specified metric name. If you include this parameter in your request, you must also include the metricNamespace parameter. Defaults to None.
        metric_namespace(str, optional): Filters results to include only those in the specified namespace. If you include this parameter in your request, you must also include the metricName parameter. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.logs.metric_filter_.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.logs.metric_filter.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="logs",
        operation="describe_metric_filters",
        op_kwargs={
            "logGroupName": log_group_name,
            "filterNamePrefix": filter_name_prefix,
            "nextToken": next_token,
            "limit": limit,
            "metricName": metric_name,
            "metricNamespace": metric_namespace,
        },
    )


async def put(
    hub,
    ctx,
    log_group_name: str,
    filter_name: str,
    filter_pattern: str,
    metric_transformations: List,
) -> None:
    r"""
    **Autogenerated function**

    Creates or updates a metric filter and associates it with the specified log group. Metric filters allow you to configure rules to extract metric data from log events ingested through PutLogEvents. The maximum number of metric filters that can be associated with a log group is 100. When you create a metric filter, you can also optionally assign a unit and dimensions to the metric that is created.  Metrics extracted from log events are charged as custom metrics. To prevent unexpected high charges, do not specify high-cardinality fields such as IPAddress or requestID as dimensions. Each different value found for a dimension is treated as a separate metric and accrues charges as a separate custom metric.  To help prevent accidental high charges, Amazon disables a metric filter if it generates 1000 different name/value pairs for the dimensions that you have specified within a certain amount of time. You can also set up a billing alarm to alert you if your charges are higher than expected. For more information, see  Creating a Billing Alarm to Monitor Your Estimated AWS Charges.

    Args:
        log_group_name(str): The name of the log group.
        filter_name(str): A name for the metric filter.
        filter_pattern(str): A filter pattern for extracting metric data out of ingested log events.
        metric_transformations(List): A collection of information that defines how metric data gets emitted.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.logs.metric_filter_.put(
                ctx,
                log_group_name=value,
                filter_name=value,
                filter_pattern=value,
                metric_transformations=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.logs.metric_filter.put log_group_name=value, filter_name=value, filter_pattern=value, metric_transformations=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="logs",
        operation="put_metric_filter",
        op_kwargs={
            "logGroupName": log_group_name,
            "filterName": filter_name,
            "filterPattern": filter_pattern,
            "metricTransformations": metric_transformations,
        },
    )


async def test(hub, ctx, filter_pattern: str, log_event_messages: List) -> Dict:
    r"""
    **Autogenerated function**

    Tests the filter pattern of a metric filter against a sample of log event messages. You can use this operation to validate the correctness of a metric filter pattern.

    Args:
        filter_pattern(str): A symbolic description of how CloudWatch Logs should interpret the data in each log event. For example, a log event can contain timestamps, IP addresses, strings, and so on. You use the filter pattern to specify what to look for in the log event message.
        log_event_messages(List): The log event messages to test.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.logs.metric_filter_.test(
                ctx, filter_pattern=value, log_event_messages=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.logs.metric_filter.test filter_pattern=value, log_event_messages=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="logs",
        operation="test_metric_filter",
        op_kwargs={
            "filterPattern": filter_pattern,
            "logEventMessages": log_event_messages,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def associate(
    hub,
    ctx,
    subnet_mappings: List,
    update_token: str = None,
    firewall_arn: str = None,
    firewall_name: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Associates the specified subnets in the Amazon VPC to the firewall. You can specify one subnet for each of the Availability Zones that the VPC spans.  This request creates an AWS Network Firewall firewall endpoint in each of the subnets. To enable the firewall's protections, you must also modify the VPC's route tables for each subnet's Availability Zone, to redirect the traffic that's coming into and going out of the zone through the firewall endpoint.

    Args:
        update_token(str, optional): An optional token that you can use for optimistic locking. Network Firewall returns a token to your requests that access the firewall. The token marks the state of the firewall resource at the time of the request.  To make an unconditional change to the firewall, omit the token in your update request. Without the token, Network Firewall performs your updates regardless of whether the firewall has changed since you last retrieved it. To make a conditional change to the firewall, provide the token in your update request. Network Firewall uses the token to ensure that the firewall hasn't changed since you last retrieved it. If it has changed, the operation fails with an InvalidTokenException. If this happens, retrieve the firewall again to get a current copy of it with a new token. Reapply your changes as needed, then try the operation again using the new token. . Defaults to None.
        firewall_arn(str, optional): The Amazon Resource Name (ARN) of the firewall. You must specify the ARN or the name, and you can specify both. . Defaults to None.
        firewall_name(str, optional): The descriptive name of the firewall. You can't change the name of a firewall after you create it. You must specify the ARN or the name, and you can specify both. . Defaults to None.
        subnet_mappings(List): The IDs of the subnets that you want to associate with the firewall. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.network_firewall.subnet.init.associate(
                ctx, subnet_mappings=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.network_firewall.subnet.init.associate subnet_mappings=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="network-firewall",
        operation="associate_subnets",
        op_kwargs={
            "UpdateToken": update_token,
            "FirewallArn": firewall_arn,
            "FirewallName": firewall_name,
            "SubnetMappings": subnet_mappings,
        },
    )


async def disassociate(
    hub,
    ctx,
    subnet_ids: List,
    update_token: str = None,
    firewall_arn: str = None,
    firewall_name: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Removes the specified subnet associations from the firewall. This removes the firewall endpoints from the subnets and removes any network filtering protections that the endpoints were providing.

    Args:
        update_token(str, optional): An optional token that you can use for optimistic locking. Network Firewall returns a token to your requests that access the firewall. The token marks the state of the firewall resource at the time of the request.  To make an unconditional change to the firewall, omit the token in your update request. Without the token, Network Firewall performs your updates regardless of whether the firewall has changed since you last retrieved it. To make a conditional change to the firewall, provide the token in your update request. Network Firewall uses the token to ensure that the firewall hasn't changed since you last retrieved it. If it has changed, the operation fails with an InvalidTokenException. If this happens, retrieve the firewall again to get a current copy of it with a new token. Reapply your changes as needed, then try the operation again using the new token. . Defaults to None.
        firewall_arn(str, optional): The Amazon Resource Name (ARN) of the firewall. You must specify the ARN or the name, and you can specify both. . Defaults to None.
        firewall_name(str, optional): The descriptive name of the firewall. You can't change the name of a firewall after you create it. You must specify the ARN or the name, and you can specify both. . Defaults to None.
        subnet_ids(List): The unique identifiers for the subnets that you want to disassociate. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.network_firewall.subnet.init.disassociate(ctx, subnet_ids=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.network_firewall.subnet.init.disassociate subnet_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="network-firewall",
        operation="disassociate_subnets",
        op_kwargs={
            "UpdateToken": update_token,
            "FirewallArn": firewall_arn,
            "FirewallName": firewall_name,
            "SubnetIds": subnet_ids,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub,
    ctx,
    task_id: str,
    report_type: str,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Information about the thing registration tasks.

    Args:
        task_id(str): The id of the task.
        report_type(str): The type of task report.
        next_token(str, optional): To retrieve the next set of results, the nextToken value from a previous response; otherwise null to receive the first set of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return per request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.thing.registration_task.report.list_all(
                ctx, task_id=value, report_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.thing.registration_task.report.list_all task_id=value, report_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="list_thing_registration_task_reports",
        op_kwargs={
            "taskId": task_id,
            "reportType": report_type,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def claim(
    hub,
    ctx,
    game_server_group_name: str,
    game_server_id: str = None,
    game_server_data: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     This operation is used with the GameLift FleetIQ solution and game server groups.  Locates an available game server and temporarily reserves it to host gameplay and players. This operation is called from a game client or client service (such as a matchmaker) to request hosting resources for a new game session. In response, GameLift FleetIQ locates an available game server, places it in CLAIMED status for 60 seconds, and returns connection information that players can use to connect to the game server.  To claim a game server, identify a game server group. You can also specify a game server ID, although this approach bypasses GameLift FleetIQ placement optimization. Optionally, include game data to pass to the game server at the start of a game session, such as a game map or player information.  When a game server is successfully claimed, connection information is returned. A claimed game server's utilization status remains AVAILABLE while the claim status is set to CLAIMED for up to 60 seconds. This time period gives the game server time to update its status to UTILIZED (using UpdateGameServer) once players join. If the game server's status is not updated within 60 seconds, the game server reverts to unclaimed status and is available to be claimed by another request. The claim time period is a fixed value and is not configurable. If you try to claim a specific game server, this request will fail in the following cases:   If the game server utilization status is UTILIZED.   If the game server claim status is CLAIMED.    When claiming a specific game server, this request will succeed even if the game server is running on an instance in DRAINING status. To avoid this, first check the instance status by calling DescribeGameServerInstances.   Learn more   GameLift FleetIQ Guide   Related actions   RegisterGameServer | ListGameServers | ClaimGameServer | DescribeGameServer | UpdateGameServer | DeregisterGameServer | All APIs by task

    Args:
        game_server_group_name(str): A unique identifier for the game server group where the game server is running. Use either the GameServerGroup name or ARN value. If you are not specifying a game server to claim, this value identifies where you want GameLift FleetIQ to look for an available game server to claim. .
        game_server_id(str, optional): A custom string that uniquely identifies the game server to claim. If this parameter is left empty, GameLift FleetIQ searches for an available game server in the specified game server group. Defaults to None.
        game_server_data(str, optional): A set of custom game server properties, formatted as a single string value. This data is passed to a game client or service when it requests information on game servers using ListGameServers or ClaimGameServer. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.game.server.init.claim(
                ctx, game_server_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.game.server.init.claim game_server_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="claim_game_server",
        op_kwargs={
            "GameServerGroupName": game_server_group_name,
            "GameServerId": game_server_id,
            "GameServerData": game_server_data,
        },
    )


async def deregister(
    hub, ctx, game_server_group_name: str, game_server_id: str
) -> None:
    r"""
    **Autogenerated function**

     This operation is used with the GameLift FleetIQ solution and game server groups.  Removes the game server from a game server group. As a result of this operation, the deregistered game server can no longer be claimed and will not be returned in a list of active game servers.  To deregister a game server, specify the game server group and game server ID. If successful, this operation emits a CloudWatch event with termination timestamp and reason.  Learn more   GameLift FleetIQ Guide   Related actions   RegisterGameServer | ListGameServers | ClaimGameServer | DescribeGameServer | UpdateGameServer | DeregisterGameServer | All APIs by task

    Args:
        game_server_group_name(str): A unique identifier for the game server group where the game server is running. Use either the GameServerGroup name or ARN value.
        game_server_id(str): A custom string that uniquely identifies the game server to deregister.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.game.server.init.deregister(
                ctx, game_server_group_name=value, game_server_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.game.server.init.deregister game_server_group_name=value, game_server_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="deregister_game_server",
        op_kwargs={
            "GameServerGroupName": game_server_group_name,
            "GameServerId": game_server_id,
        },
    )


async def describe(hub, ctx, game_server_group_name: str, game_server_id: str) -> Dict:
    r"""
    **Autogenerated function**

     This operation is used with the GameLift FleetIQ solution and game server groups.  Retrieves information for a registered game server. Information includes game server status, health check info, and the instance that the game server is running on.  To retrieve game server information, specify the game server ID. If successful, the requested game server object is returned.   Learn more   GameLift FleetIQ Guide   Related actions   RegisterGameServer | ListGameServers | ClaimGameServer | DescribeGameServer | UpdateGameServer | DeregisterGameServer | All APIs by task

    Args:
        game_server_group_name(str): A unique identifier for the game server group where the game server is running. Use either the GameServerGroup name or ARN value.
        game_server_id(str): A custom string that uniquely identifies the game server information to be retrieved.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.game.server.init.describe(
                ctx, game_server_group_name=value, game_server_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.game.server.init.describe game_server_group_name=value, game_server_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="describe_game_server",
        op_kwargs={
            "GameServerGroupName": game_server_group_name,
            "GameServerId": game_server_id,
        },
    )


async def list_all(
    hub,
    ctx,
    game_server_group_name: str,
    sort_order: str = None,
    limit: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     This operation is used with the GameLift FleetIQ solution and game server groups.  Retrieves information on all game servers that are currently active in a specified game server group. You can opt to sort the list by game server age. Use the pagination parameters to retrieve results in a set of sequential segments.   Learn more   GameLift FleetIQ Guide   Related actions   RegisterGameServer | ListGameServers | ClaimGameServer | DescribeGameServer | UpdateGameServer | DeregisterGameServer | All APIs by task

    Args:
        game_server_group_name(str): An identifier for the game server group to retrieve a list of game servers from. Use either the GameServerGroup name or ARN value.
        sort_order(str, optional): Indicates how to sort the returned data based on game server registration timestamp. Use ASCENDING to retrieve oldest game servers first, or use DESCENDING to retrieve newest game servers first. If this parameter is left empty, game servers are returned in no particular order. Defaults to None.
        limit(int, optional): The maximum number of results to return. Use this parameter with NextToken to get results as a set of sequential pages. Defaults to None.
        next_token(str, optional): A token that indicates the start of the next sequential page of results. Use the token that is returned with a previous call to this operation. To start at the beginning of the result set, do not specify a value. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.game.server.init.list_all(
                ctx, game_server_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.game.server.init.list_all game_server_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="list_game_servers",
        op_kwargs={
            "GameServerGroupName": game_server_group_name,
            "SortOrder": sort_order,
            "Limit": limit,
            "NextToken": next_token,
        },
    )


async def register(
    hub,
    ctx,
    game_server_group_name: str,
    game_server_id: str,
    instance_id: str,
    connection_info: str = None,
    game_server_data: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     This operation is used with the GameLift FleetIQ solution and game server groups.  Creates a new game server resource and notifies GameLift FleetIQ that the game server is ready to host gameplay and players. This operation is called by a game server process that is running on an instance in a game server group. Registering game servers enables GameLift FleetIQ to track available game servers and enables game clients and services to claim a game server for a new game session.  To register a game server, identify the game server group and instance where the game server is running, and provide a unique identifier for the game server. You can also include connection and game server data. When a game client or service requests a game server by calling ClaimGameServer, this information is returned in the response. Once a game server is successfully registered, it is put in status AVAILABLE. A request to register a game server may fail if the instance it is running on is in the process of shutting down as part of instance balancing or scale-down activity.   Learn more   GameLift FleetIQ Guide   Related actions   RegisterGameServer | ListGameServers | ClaimGameServer | DescribeGameServer | UpdateGameServer | DeregisterGameServer | All APIs by task

    Args:
        game_server_group_name(str): A unique identifier for the game server group where the game server is running. Use either the GameServerGroup name or ARN value.
        game_server_id(str): A custom string that uniquely identifies the game server to register. Game server IDs are developer-defined and must be unique across all game server groups in your AWS account.
        instance_id(str): The unique identifier for the instance where the game server is running. This ID is available in the instance metadata. EC2 instance IDs use a 17-character format, for example: i-1234567890abcdef0.
        connection_info(str, optional): Information that is needed to make inbound client connections to the game server. This might include the IP address and port, DNS name, and other information. Defaults to None.
        game_server_data(str, optional): A set of custom game server properties, formatted as a single string value. This data is passed to a game client or service when it requests information on game servers using ListGameServers or ClaimGameServer. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.game.server.init.register(
                ctx, game_server_group_name=value, game_server_id=value, instance_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.game.server.init.register game_server_group_name=value, game_server_id=value, instance_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="register_game_server",
        op_kwargs={
            "GameServerGroupName": game_server_group_name,
            "GameServerId": game_server_id,
            "InstanceId": instance_id,
            "ConnectionInfo": connection_info,
            "GameServerData": game_server_data,
        },
    )


async def update(
    hub,
    ctx,
    game_server_group_name: str,
    game_server_id: str,
    game_server_data: str = None,
    utilization_status: str = None,
    health_check: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     This operation is used with the GameLift FleetIQ solution and game server groups.  Updates information about a registered game server to help GameLift FleetIQ to track game server availability. This operation is called by a game server process that is running on an instance in a game server group.  Use this operation to update the following types of game server information. You can make all three types of updates in the same request:   To update the game server's utilization status, identify the game server and game server group and specify the current utilization status. Use this status to identify when game servers are currently hosting games and when they are available to be claimed.   To report health status, identify the game server and game server group and set health check to HEALTHY. If a game server does not report health status for a certain length of time, the game server is no longer considered healthy. As a result, it will be eventually deregistered from the game server group to avoid affecting utilization metrics. The best practice is to report health every 60 seconds.   To change game server metadata, provide updated game server data.   Once a game server is successfully updated, the relevant statuses and timestamps are updated.  Learn more   GameLift FleetIQ Guide   Related actions   RegisterGameServer | ListGameServers | ClaimGameServer | DescribeGameServer | UpdateGameServer | DeregisterGameServer | All APIs by task

    Args:
        game_server_group_name(str): A unique identifier for the game server group where the game server is running. Use either the GameServerGroup name or ARN value.
        game_server_id(str): A custom string that uniquely identifies the game server to update.
        game_server_data(str, optional): A set of custom game server properties, formatted as a single string value. This data is passed to a game client or service when it requests information on game servers using ListGameServers or ClaimGameServer. . Defaults to None.
        utilization_status(str, optional): Indicates whether the game server is available or is currently hosting gameplay. Defaults to None.
        health_check(str, optional): Indicates health status of the game server. A request that includes this parameter updates the game server's LastHealthCheckTime timestamp. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.game.server.init.update(
                ctx, game_server_group_name=value, game_server_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.game.server.init.update game_server_group_name=value, game_server_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="update_game_server",
        op_kwargs={
            "GameServerGroupName": game_server_group_name,
            "GameServerId": game_server_id,
            "GameServerData": game_server_data,
            "UtilizationStatus": utilization_status,
            "HealthCheck": health_check,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def update(hub, ctx, job_id: str, shipment_state: str) -> Dict:
    r"""
    **Autogenerated function**

    Updates the state when a shipment state changes to a different state.

    Args:
        job_id(str): The job ID of the job whose shipment date you want to update, for example JID123e4567-e89b-12d3-a456-426655440000.
        shipment_state(str): The state of a device when it is being shipped.  Set to RECEIVED when the device arrives at your location. Set to RETURNED when you have returned the device to AWS.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.snowball.job.shipment_state.update(
                ctx, job_id=value, shipment_state=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.snowball.job.shipment_state.update job_id=value, shipment_state=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="snowball",
        operation="update_job_shipment_state",
        op_kwargs={"JobId": job_id, "ShipmentState": shipment_state},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    global_replication_group_id_suffix: str,
    primary_replication_group_id: str,
    global_replication_group_description: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Global Datastore for Redis offers fully managed, fast, reliable and secure cross-region replication. Using Global Datastore for Redis, you can create cross-region read replica clusters for ElastiCache for Redis to enable low-latency reads and disaster recovery across regions. For more information, see Replication Across Regions Using Global Datastore.    The GlobalReplicationGroupIdSuffix is the name of the Global datastore.   The PrimaryReplicationGroupId represents the name of the primary cluster that accepts writes and will replicate updates to the secondary cluster.

    Args:
        global_replication_group_id_suffix(str): The suffix name of a Global datastore. Amazon ElastiCache automatically applies a prefix to the Global datastore ID when it is created. Each AWS Region has its own prefix. For instance, a Global datastore ID created in the US-West-1 region will begin with "dsdfu" along with the suffix name you provide. The suffix, combined with the auto-generated prefix, guarantees uniqueness of the Global datastore name across multiple regions.  For a full list of AWS Regions and their respective Global datastore iD prefixes, see Using the AWS CLI with Global datastores .
        global_replication_group_description(str, optional): Provides details of the Global datastore. Defaults to None.
        primary_replication_group_id(str): The name of the primary cluster that accepts writes and will replicate updates to the secondary cluster.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticache.global_replication_group.create(
                ctx, global_replication_group_id_suffix=value, primary_replication_group_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticache.global_replication_group.create global_replication_group_id_suffix=value, primary_replication_group_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticache",
        operation="create_global_replication_group",
        op_kwargs={
            "GlobalReplicationGroupIdSuffix": global_replication_group_id_suffix,
            "GlobalReplicationGroupDescription": global_replication_group_description,
            "PrimaryReplicationGroupId": primary_replication_group_id,
        },
    )


async def delete(
    hub, ctx, global_replication_group_id: str, retain_primary_replication_group: bool
) -> Dict:
    r"""
    **Autogenerated function**

    Deleting a Global datastore is a two-step process:    First, you must DisassociateGlobalReplicationGroup to remove the secondary clusters in the Global datastore.   Once the Global datastore contains only the primary cluster, you can use the DeleteGlobalReplicationGroup API to delete the Global datastore while retainining the primary cluster using RetainPrimaryReplicationGroup=true.   Since the Global Datastore has only a primary cluster, you can delete the Global Datastore while retaining the primary by setting RetainPrimaryReplicationGroup=true. The primary cluster is never deleted when deleting a Global Datastore. It can only be deleted when it no longer is associated with any Global Datastore. When you receive a successful response from this operation, Amazon ElastiCache immediately begins deleting the selected resources; you cannot cancel or revert this operation.

    Args:
        global_replication_group_id(str): The name of the Global datastore.
        retain_primary_replication_group(bool): The primary replication group is retained as a standalone replication group. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticache.global_replication_group.delete(
                ctx, global_replication_group_id=value, retain_primary_replication_group=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticache.global_replication_group.delete global_replication_group_id=value, retain_primary_replication_group=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticache",
        operation="delete_global_replication_group",
        op_kwargs={
            "GlobalReplicationGroupId": global_replication_group_id,
            "RetainPrimaryReplicationGroup": retain_primary_replication_group,
        },
    )


async def describe_all(
    hub,
    ctx,
    global_replication_group_id: str = None,
    max_records: int = None,
    marker: str = None,
    show_member_info: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about a particular global replication group. If no identifier is specified, returns information about all Global datastores.

    Args:
        global_replication_group_id(str, optional): The name of the Global datastore. Defaults to None.
        max_records(int, optional): The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a marker is included in the response so that the remaining results can be retrieved. . Defaults to None.
        marker(str, optional): An optional marker returned from a prior request. Use this marker for pagination of results from this operation. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords. . Defaults to None.
        show_member_info(bool, optional): Returns the list of members that comprise the Global datastore. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticache.global_replication_group.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticache.global_replication_group.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticache",
        operation="describe_global_replication_groups",
        op_kwargs={
            "GlobalReplicationGroupId": global_replication_group_id,
            "MaxRecords": max_records,
            "Marker": marker,
            "ShowMemberInfo": show_member_info,
        },
    )


async def disassociate(
    hub,
    ctx,
    global_replication_group_id: str,
    replication_group_id: str,
    replication_group_region: str,
) -> Dict:
    r"""
    **Autogenerated function**

    Remove a secondary cluster from the Global datastore using the Global datastore name. The secondary cluster will no longer receive updates from the primary cluster, but will remain as a standalone cluster in that AWS region.

    Args:
        global_replication_group_id(str): The name of the Global datastore.
        replication_group_id(str): The name of the secondary cluster you wish to remove from the Global datastore.
        replication_group_region(str): The AWS region of secondary cluster you wish to remove from the Global datastore.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticache.global_replication_group.disassociate(
                ctx,
                global_replication_group_id=value,
                replication_group_id=value,
                replication_group_region=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticache.global_replication_group.disassociate global_replication_group_id=value, replication_group_id=value, replication_group_region=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticache",
        operation="disassociate_global_replication_group",
        op_kwargs={
            "GlobalReplicationGroupId": global_replication_group_id,
            "ReplicationGroupId": replication_group_id,
            "ReplicationGroupRegion": replication_group_region,
        },
    )


async def failover(
    hub,
    ctx,
    global_replication_group_id: str,
    primary_region: str,
    primary_replication_group_id: str,
) -> Dict:
    r"""
    **Autogenerated function**

    Used to failover the primary region to a selected secondary region. The selected secondary region will become primary, and all other clusters will become secondary.

    Args:
        global_replication_group_id(str): The name of the Global datastore.
        primary_region(str): The AWS region of the primary cluster of the Global datastore.
        primary_replication_group_id(str): The name of the primary replication group.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticache.global_replication_group.failover(
                ctx,
                global_replication_group_id=value,
                primary_region=value,
                primary_replication_group_id=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticache.global_replication_group.failover global_replication_group_id=value, primary_region=value, primary_replication_group_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticache",
        operation="failover_global_replication_group",
        op_kwargs={
            "GlobalReplicationGroupId": global_replication_group_id,
            "PrimaryRegion": primary_region,
            "PrimaryReplicationGroupId": primary_replication_group_id,
        },
    )


async def modify(
    hub,
    ctx,
    global_replication_group_id: str,
    apply_immediately: bool,
    cache_node_type: str = None,
    engine_version: str = None,
    cache_parameter_group_name: str = None,
    global_replication_group_description: str = None,
    automatic_failover_enabled: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies the settings for a Global datastore.

    Args:
        global_replication_group_id(str): The name of the Global datastore.
        apply_immediately(bool): This parameter causes the modifications in this request and any pending modifications to be applied, asynchronously and as soon as possible. Modifications to Global Replication Groups cannot be requested to be applied in PreferredMaintenceWindow. .
        cache_node_type(str, optional): A valid cache node type that you want to scale this Global datastore to. Defaults to None.
        engine_version(str, optional): The upgraded version of the cache engine to be run on the clusters in the Global datastore. . Defaults to None.
        cache_parameter_group_name(str, optional): The name of the cache parameter group to use with the Global datastore. It must be compatible with the major engine version used by the Global datastore. Defaults to None.
        global_replication_group_description(str, optional): A description of the Global datastore. Defaults to None.
        automatic_failover_enabled(bool, optional): Determines whether a read replica is automatically promoted to read/write primary if the existing primary encounters a failure. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticache.global_replication_group.modify(
                ctx, global_replication_group_id=value, apply_immediately=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticache.global_replication_group.modify global_replication_group_id=value, apply_immediately=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticache",
        operation="modify_global_replication_group",
        op_kwargs={
            "GlobalReplicationGroupId": global_replication_group_id,
            "ApplyImmediately": apply_immediately,
            "CacheNodeType": cache_node_type,
            "EngineVersion": engine_version,
            "CacheParameterGroupName": cache_parameter_group_name,
            "GlobalReplicationGroupDescription": global_replication_group_description,
            "AutomaticFailoverEnabled": automatic_failover_enabled,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, service_code: str, quota_code: str, aws_region: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the quota increase request for the specified quota from your quota request template.

    Args:
        service_code(str): The service identifier.
        quota_code(str): The quota identifier.
        aws_region(str): The AWS Region.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.service_quotas.service.quota.increase.request.from_template.delete(
                ctx, service_code=value, quota_code=value, aws_region=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.service_quotas.service.quota.increase.request.from_template.delete service_code=value, quota_code=value, aws_region=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="service-quotas",
        operation="delete_service_quota_increase_request_from_template",
        op_kwargs={
            "ServiceCode": service_code,
            "QuotaCode": quota_code,
            "AwsRegion": aws_region,
        },
    )


async def get(hub, ctx, service_code: str, quota_code: str, aws_region: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about the specified quota increase request in your quota request template.

    Args:
        service_code(str): The service identifier.
        quota_code(str): The quota identifier.
        aws_region(str): The AWS Region.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.service_quotas.service.quota.increase.request.from_template.get(
                ctx, service_code=value, quota_code=value, aws_region=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.service_quotas.service.quota.increase.request.from_template.get service_code=value, quota_code=value, aws_region=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="service-quotas",
        operation="get_service_quota_increase_request_from_template",
        op_kwargs={
            "ServiceCode": service_code,
            "QuotaCode": quota_code,
            "AwsRegion": aws_region,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__func_alias__ = {"list_": "list"}


async def list_(hub, ctx, resource_name: str, filters: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists all tags on an Amazon DocumentDB resource.

    Args:
        resource_name(str): The Amazon DocumentDB resource with tags to be listed. This value is an Amazon Resource Name (ARN).
        filters(List, optional): This parameter is not currently supported. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.docdb.tags.for_resource.list(ctx, resource_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.docdb.tags.for_resource.list resource_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="docdb",
        operation="list_tags_for_resource",
        op_kwargs={"ResourceName": resource_name, "Filters": filters},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub, ctx, queue_name: str, queue_owner_aws_account_id: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the URL of an existing Amazon SQS queue. To access a queue that belongs to another AWS account, use the QueueOwnerAWSAccountId parameter to specify the account ID of the queue's owner. The queue's owner must grant you permission to access the queue. For more information about shared queue access, see  AddPermission  or see Allow Developers to Write Messages to a Shared Queue in the Amazon SQS Developer Guide.

    Args:
        queue_name(str): The name of the queue whose URL must be fetched. Maximum 80 characters. Valid values: alphanumeric characters, hyphens (-), and underscores (_). Queue URLs and names are case-sensitive.
        queue_owner_aws_account_id(str, optional): The account ID of the account that created the queue. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sqs.queue.url.get(ctx, queue_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sqs.queue.url.get queue_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sqs",
        operation="get_queue_url",
        op_kwargs={
            "QueueName": queue_name,
            "QueueOwnerAWSAccountId": queue_owner_aws_account_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get(
    hub,
    ctx,
    job_ids: List,
    name: str = None,
    company: str = None,
    phone_number: str = None,
    country: str = None,
    state_or_province: str = None,
    city: str = None,
    postal_code: str = None,
    street1: str = None,
    street2: str = None,
    street3: str = None,
    api_version: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    This operation generates a pre-paid UPS shipping label that you will use to ship your device to AWS for processing.

    Args:
        job_ids(List): .
        name(str, optional): Specifies the name of the person responsible for shipping this package. Defaults to None.
        company(str, optional): Specifies the name of the company that will ship this package. Defaults to None.
        phone_number(str, optional): Specifies the phone number of the person responsible for shipping this package. Defaults to None.
        country(str, optional): Specifies the name of your country for the return address. Defaults to None.
        state_or_province(str, optional): Specifies the name of your state or your province for the return address. Defaults to None.
        city(str, optional): Specifies the name of your city for the return address. Defaults to None.
        postal_code(str, optional): Specifies the postal code for the return address. Defaults to None.
        street1(str, optional): Specifies the first part of the street address for the return address, for example 1234 Main Street. Defaults to None.
        street2(str, optional): Specifies the optional second part of the street address for the return address, for example Suite 100. Defaults to None.
        street3(str, optional): Specifies the optional third part of the street address for the return address, for example c/o Jane Doe. Defaults to None.
        api_version(str, optional): Specifies the version of the client tool. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.importexport.shipping_label.get(ctx, job_ids=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.importexport.shipping_label.get job_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="importexport",
        operation="get_shipping_label",
        op_kwargs={
            "jobIds": job_ids,
            "name": name,
            "company": company,
            "phoneNumber": phone_number,
            "country": country,
            "stateOrProvince": state_or_province,
            "city": city,
            "postalCode": postal_code,
            "street1": street1,
            "street2": street2,
            "street3": street3,
            "APIVersion": api_version,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def attach(hub, ctx, elastic_load_balancer_name: str, layer_id: str) -> None:
    r"""
    **Autogenerated function**

    Attaches an Elastic Load Balancing load balancer to a specified layer. AWS OpsWorks Stacks does not support Application Load Balancer. You can only use Classic Load Balancer with AWS OpsWorks Stacks. For more information, see Elastic Load Balancing.  You must create the Elastic Load Balancing instance separately, by using the Elastic Load Balancing console, API, or CLI. For more information, see  Elastic Load Balancing Developer Guide.   Required Permissions: To use this action, an IAM user must have a Manage permissions level for the stack, or an attached policy that explicitly grants permissions. For more information on user permissions, see Managing User Permissions.

    Args:
        elastic_load_balancer_name(str): The Elastic Load Balancing instance's name.
        layer_id(str): The ID of the layer to which the Elastic Load Balancing instance is to be attached.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.elastic.load_balancer.attach(
                ctx, elastic_load_balancer_name=value, layer_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.elastic.load_balancer.attach elastic_load_balancer_name=value, layer_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="attach_elastic_load_balancer",
        op_kwargs={
            "ElasticLoadBalancerName": elastic_load_balancer_name,
            "LayerId": layer_id,
        },
    )


async def describe_all(hub, ctx, stack_id: str = None, layer_ids: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Describes a stack's Elastic Load Balancing instances.  This call accepts only one resource-identifying parameter.   Required Permissions: To use this action, an IAM user must have a Show, Deploy, or Manage permissions level for the stack, or an attached policy that explicitly grants permissions. For more information about user permissions, see Managing User Permissions.

    Args:
        stack_id(str, optional): A stack ID. The action describes the stack's Elastic Load Balancing instances. Defaults to None.
        layer_ids(List, optional): A list of layer IDs. The action describes the Elastic Load Balancing instances for the specified layers. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.elastic.load_balancer.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.elastic.load_balancer.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="describe_elastic_load_balancers",
        op_kwargs={"StackId": stack_id, "LayerIds": layer_ids},
    )


async def detach(hub, ctx, elastic_load_balancer_name: str, layer_id: str) -> None:
    r"""
    **Autogenerated function**

    Detaches a specified Elastic Load Balancing instance from its layer.  Required Permissions: To use this action, an IAM user must have a Manage permissions level for the stack, or an attached policy that explicitly grants permissions. For more information on user permissions, see Managing User Permissions.

    Args:
        elastic_load_balancer_name(str): The Elastic Load Balancing instance's name.
        layer_id(str): The ID of the layer that the Elastic Load Balancing instance is attached to.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.elastic.load_balancer.detach(
                ctx, elastic_load_balancer_name=value, layer_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.elastic.load_balancer.detach elastic_load_balancer_name=value, layer_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="detach_elastic_load_balancer",
        op_kwargs={
            "ElasticLoadBalancerName": elastic_load_balancer_name,
            "LayerId": layer_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    training_job_name: str,
    algorithm_specification: Dict,
    role_arn: str,
    output_data_config: Dict,
    resource_config: Dict,
    stopping_condition: Dict,
    hyper_parameters: Dict = None,
    input_data_config: List = None,
    vpc_config: Dict = None,
    tags: List = None,
    enable_network_isolation: bool = None,
    enable_inter_container_traffic_encryption: bool = None,
    enable_managed_spot_training: bool = None,
    checkpoint_config: Dict = None,
    debug_hook_config: Dict = None,
    debug_rule_configurations: List = None,
    tensor_board_output_config: Dict = None,
    experiment_config: Dict = None,
    profiler_config: Dict = None,
    profiler_rule_configurations: List = None,
    environment: Dict = None,
    retry_strategy: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Starts a model training job. After training completes, Amazon SageMaker saves the resulting model artifacts to an Amazon S3 location that you specify.  If you choose to host your model using Amazon SageMaker hosting services, you can use the resulting model artifacts as part of the model. You can also use the artifacts in a machine learning service other than Amazon SageMaker, provided that you know how to use them for inference.  In the request body, you provide the following:     AlgorithmSpecification - Identifies the training algorithm to use.     HyperParameters - Specify these algorithm-specific parameters to enable the estimation of model parameters during training. Hyperparameters can be tuned to optimize this learning process. For a list of hyperparameters for each training algorithm provided by Amazon SageMaker, see Algorithms.     InputDataConfig - Describes the training dataset and the Amazon S3, EFS, or FSx location where it is stored.    OutputDataConfig - Identifies the Amazon S3 bucket where you want Amazon SageMaker to save the results of model training.     ResourceConfig - Identifies the resources, ML compute instances, and ML storage volumes to deploy for model training. In distributed training, you specify more than one instance.     EnableManagedSpotTraining - Optimize the cost of training machine learning models by up to 80% by using Amazon EC2 Spot instances. For more information, see Managed Spot Training.     RoleArn - The Amazon Resource Name (ARN) that Amazon SageMaker assumes to perform tasks on your behalf during model training. You must grant this role the necessary permissions so that Amazon SageMaker can successfully complete model training.     StoppingCondition - To help cap training costs, use MaxRuntimeInSeconds to set a time limit for training. Use MaxWaitTimeInSeconds to specify how long a managed spot training job has to complete.     Environment - The environment variables to set in the Docker container.    RetryStrategy - The number of times to retry the job when the job fails due to an InternalServerError.    For more information about Amazon SageMaker, see How It Works.

    Args:
        training_job_name(str): The name of the training job. The name must be unique within an Amazon Web Services Region in an Amazon Web Services account. .
        hyper_parameters(Dict, optional): Algorithm-specific parameters that influence the quality of the model. You set hyperparameters before you start the learning process. For a list of hyperparameters for each training algorithm provided by Amazon SageMaker, see Algorithms.  You can specify a maximum of 100 hyperparameters. Each hyperparameter is a key-value pair. Each key and value is limited to 256 characters, as specified by the Length Constraint. . Defaults to None.
        algorithm_specification(Dict): The registry path of the Docker image that contains the training algorithm and algorithm-specific metadata, including the input mode. For more information about algorithms provided by Amazon SageMaker, see Algorithms. For information about providing your own algorithms, see Using Your Own Algorithms with Amazon SageMaker. .
        role_arn(str): The Amazon Resource Name (ARN) of an IAM role that Amazon SageMaker can assume to perform tasks on your behalf.  During model training, Amazon SageMaker needs your permission to read input data from an S3 bucket, download a Docker image that contains training code, write model artifacts to an S3 bucket, write logs to Amazon CloudWatch Logs, and publish metrics to Amazon CloudWatch. You grant permissions for all of these tasks to an IAM role. For more information, see Amazon SageMaker Roles.   To be able to pass this role to Amazon SageMaker, the caller of this API must have the iam:PassRole permission. .
        input_data_config(List, optional): An array of Channel objects. Each channel is a named input source. InputDataConfig describes the input data and its location.  Algorithms can accept input data from one or more channels. For example, an algorithm might have two channels of input data, training_data and validation_data. The configuration for each channel provides the S3, EFS, or FSx location where the input data is stored. It also provides information about the stored data: the MIME type, compression method, and whether the data is wrapped in RecordIO format.  Depending on the input mode that the algorithm supports, Amazon SageMaker either copies input data files from an S3 bucket to a local directory in the Docker container, or makes it available as input streams. For example, if you specify an EFS location, input data files will be made available as input streams. They do not need to be downloaded. Defaults to None.
        output_data_config(Dict): Specifies the path to the S3 location where you want to store model artifacts. Amazon SageMaker creates subfolders for the artifacts. .
        resource_config(Dict): The resources, including the ML compute instances and ML storage volumes, to use for model training.  ML storage volumes store model artifacts and incremental states. Training algorithms might also use ML storage volumes for scratch space. If you want Amazon SageMaker to use the ML storage volume to store the training data, choose File as the TrainingInputMode in the algorithm specification. For distributed training algorithms, specify an instance count greater than 1.
        vpc_config(Dict, optional): A VpcConfig object that specifies the VPC that you want your training job to connect to. Control access to and from your training container by configuring the VPC. For more information, see Protect Training Jobs by Using an Amazon Virtual Private Cloud. Defaults to None.
        stopping_condition(Dict): Specifies a limit to how long a model training job can run. It also specifies how long a managed Spot training job has to complete. When the job reaches the time limit, Amazon SageMaker ends the training job. Use this API to cap model training costs. To stop a job, Amazon SageMaker sends the algorithm the SIGTERM signal, which delays job termination for 120 seconds. Algorithms can use this 120-second window to save the model artifacts, so the results of training are not lost. .
        tags(List, optional): An array of key-value pairs. You can use tags to categorize your Amazon Web Services resources in different ways, for example, by purpose, owner, or environment. For more information, see Tagging Amazon Web Services Resources. Defaults to None.
        enable_network_isolation(bool, optional): Isolates the training container. No inbound or outbound network calls can be made, except for calls between peers within a training cluster for distributed training. If you enable network isolation for training jobs that are configured to use a VPC, Amazon SageMaker downloads and uploads customer data and model artifacts through the specified VPC, but the training container does not have network access. Defaults to None.
        enable_inter_container_traffic_encryption(bool, optional): To encrypt all communications between ML compute instances in distributed training, choose True. Encryption provides greater security for distributed training, but training might take longer. How long it takes depends on the amount of communication between compute instances, especially if you use a deep learning algorithm in distributed training. For more information, see Protect Communications Between ML Compute Instances in a Distributed Training Job. Defaults to None.
        enable_managed_spot_training(bool, optional): To train models using managed spot training, choose True. Managed spot training provides a fully managed and scalable infrastructure for training machine learning models. this option is useful when training jobs can be interrupted and when there is flexibility when the training job is run.  The complete and intermediate results of jobs are stored in an Amazon S3 bucket, and can be used as a starting point to train models incrementally. Amazon SageMaker provides metrics and logs in CloudWatch. They can be used to see when managed spot training jobs are running, interrupted, resumed, or completed. . Defaults to None.
        checkpoint_config(Dict, optional): Contains information about the output location for managed spot training checkpoint data. Defaults to None.
        debug_hook_config(Dict, optional): Configuration information for the Debugger hook parameters, metric and tensor collections, and storage paths. To learn more about how to configure the DebugHookConfig parameter, see Use the SageMaker and Debugger Configuration API Operations to Create, Update, and Debug Your Training Job. Defaults to None.
        debug_rule_configurations(List, optional): Configuration information for Debugger rules for debugging output tensors. Defaults to None.
        tensor_board_output_config(Dict, optional): Configuration of storage locations for the Debugger TensorBoard output data. Defaults to None.
        experiment_config(Dict, optional): Associates a SageMaker job as a trial component with an experiment and trial. Specified when you call the following APIs:    CreateProcessingJob     CreateTrainingJob     CreateTransformJob   . Defaults to None.
        profiler_config(Dict, optional): Configuration information for Debugger system monitoring, framework profiling, and storage paths. Defaults to None.
        profiler_rule_configurations(List, optional): Configuration information for Debugger rules for profiling system and framework metrics. Defaults to None.
        environment(Dict, optional): The environment variables to set in the Docker container. Defaults to None.
        retry_strategy(Dict, optional): The number of times to retry the job when the job fails due to an InternalServerError. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.training_job.create(
                ctx,
                training_job_name=value,
                algorithm_specification=value,
                role_arn=value,
                output_data_config=value,
                resource_config=value,
                stopping_condition=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.training_job.create training_job_name=value, algorithm_specification=value, role_arn=value, output_data_config=value, resource_config=value, stopping_condition=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="create_training_job",
        op_kwargs={
            "TrainingJobName": training_job_name,
            "HyperParameters": hyper_parameters,
            "AlgorithmSpecification": algorithm_specification,
            "RoleArn": role_arn,
            "InputDataConfig": input_data_config,
            "OutputDataConfig": output_data_config,
            "ResourceConfig": resource_config,
            "VpcConfig": vpc_config,
            "StoppingCondition": stopping_condition,
            "Tags": tags,
            "EnableNetworkIsolation": enable_network_isolation,
            "EnableInterContainerTrafficEncryption": enable_inter_container_traffic_encryption,
            "EnableManagedSpotTraining": enable_managed_spot_training,
            "CheckpointConfig": checkpoint_config,
            "DebugHookConfig": debug_hook_config,
            "DebugRuleConfigurations": debug_rule_configurations,
            "TensorBoardOutputConfig": tensor_board_output_config,
            "ExperimentConfig": experiment_config,
            "ProfilerConfig": profiler_config,
            "ProfilerRuleConfigurations": profiler_rule_configurations,
            "Environment": environment,
            "RetryStrategy": retry_strategy,
        },
    )


async def describe(hub, ctx, training_job_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about a training job.  Some of the attributes below only appear if the training job successfully starts. If the training job fails, TrainingJobStatus is Failed and, depending on the FailureReason, attributes like TrainingStartTime, TrainingTimeInSeconds, TrainingEndTime, and BillableTimeInSeconds may not be present in the response.

    Args:
        training_job_name(str): The name of the training job.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.training_job.describe(ctx, training_job_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.training_job.describe training_job_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="describe_training_job",
        op_kwargs={"TrainingJobName": training_job_name},
    )


async def list_all(
    hub,
    ctx,
    next_token: str = None,
    max_results: int = None,
    creation_time_after: str = None,
    creation_time_before: str = None,
    last_modified_time_after: str = None,
    last_modified_time_before: str = None,
    name_contains: str = None,
    status_equals: str = None,
    sort_by: str = None,
    sort_order: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists training jobs.  When StatusEquals and MaxResults are set at the same time, the MaxResults number of training jobs are first retrieved ignoring the StatusEquals parameter and then they are filtered by the StatusEquals parameter, which is returned as a response. For example, if ListTrainingJobs is invoked with the following parameters:  { ... MaxResults: 100, StatusEquals: InProgress ... }  First, 100 trainings jobs with any status, including those other than InProgress, are selected (sorted according to the creation time, from the most current to the oldest). Next, those with a status of InProgress are returned. You can quickly test the API using the following Amazon Web Services CLI code.  aws sagemaker list-training-jobs --max-results 100 --status-equals InProgress

    Args:
        next_token(str, optional): If the result of the previous ListTrainingJobs request was truncated, the response includes a NextToken. To retrieve the next set of training jobs, use the token in the next request. . Defaults to None.
        max_results(int, optional): The maximum number of training jobs to return in the response. Defaults to None.
        creation_time_after(str, optional): A filter that returns only training jobs created after the specified time (timestamp). Defaults to None.
        creation_time_before(str, optional): A filter that returns only training jobs created before the specified time (timestamp). Defaults to None.
        last_modified_time_after(str, optional): A filter that returns only training jobs modified after the specified time (timestamp). Defaults to None.
        last_modified_time_before(str, optional): A filter that returns only training jobs modified before the specified time (timestamp). Defaults to None.
        name_contains(str, optional): A string in the training job name. This filter returns only training jobs whose name contains the specified string. Defaults to None.
        status_equals(str, optional): A filter that retrieves only training jobs with a specific status. Defaults to None.
        sort_by(str, optional): The field to sort results by. The default is CreationTime. Defaults to None.
        sort_order(str, optional): The sort order for results. The default is Ascending. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.training_job.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.training_job.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="list_training_jobs",
        op_kwargs={
            "NextToken": next_token,
            "MaxResults": max_results,
            "CreationTimeAfter": creation_time_after,
            "CreationTimeBefore": creation_time_before,
            "LastModifiedTimeAfter": last_modified_time_after,
            "LastModifiedTimeBefore": last_modified_time_before,
            "NameContains": name_contains,
            "StatusEquals": status_equals,
            "SortBy": sort_by,
            "SortOrder": sort_order,
        },
    )


async def stop(hub, ctx, training_job_name: str) -> None:
    r"""
    **Autogenerated function**

    Stops a training job. To stop a job, Amazon SageMaker sends the algorithm the SIGTERM signal, which delays job termination for 120 seconds. Algorithms might use this 120-second window to save the model artifacts, so the results of the training is not lost.  When it receives a StopTrainingJob request, Amazon SageMaker changes the status of the job to Stopping. After Amazon SageMaker stops the job, it sets the status to Stopped.

    Args:
        training_job_name(str): The name of the training job to stop.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.training_job.stop(ctx, training_job_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.training_job.stop training_job_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="stop_training_job",
        op_kwargs={"TrainingJobName": training_job_name},
    )


async def update(
    hub,
    ctx,
    training_job_name: str,
    profiler_config: Dict = None,
    profiler_rule_configurations: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Update a model training job to request a new Debugger profiling configuration.

    Args:
        training_job_name(str): The name of a training job to update the Debugger profiling configuration.
        profiler_config(Dict, optional): Configuration information for Debugger system monitoring, framework profiling, and storage paths. Defaults to None.
        profiler_rule_configurations(List, optional): Configuration information for Debugger rules for profiling system and framework metrics. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.training_job.update(ctx, training_job_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.training_job.update training_job_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="update_training_job",
        op_kwargs={
            "TrainingJobName": training_job_name,
            "ProfilerConfig": profiler_config,
            "ProfilerRuleConfigurations": profiler_rule_configurations,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub,
    ctx,
    rest_api_id: str,
    stage_name: str,
    export_type: str,
    parameters: Dict = None,
    accepts: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Exports a deployed version of a RestApi in a specified format.

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        stage_name(str): [Required] The name of the Stage that will be exported.
        export_type(str): [Required] The type of export. Acceptable values are 'oas30' for OpenAPI 3.0.x and 'swagger' for Swagger/OpenAPI 2.0.
        parameters(Dict, optional): A key-value map of query string parameters that specify properties of the export, depending on the requested exportType. For exportType oas30 and swagger, any combination of the following parameters are supported: extensions='integrations' or extensions='apigateway' will export the API with x-amazon-apigateway-integration extensions. extensions='authorizers' will export the API with x-amazon-apigateway-authorizer extensions. postman will export the API with Postman extensions, allowing for import to the Postman tool. Defaults to None.
        accepts(str, optional): The content-type of the export, for example application/json. Currently application/json and application/yaml are supported for exportType ofoas30 and swagger. This should be specified in the Accept header for direct API requests. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.export.get(
                ctx, rest_api_id=value, stage_name=value, export_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.export.get rest_api_id=value, stage_name=value, export_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="get_export",
        op_kwargs={
            "restApiId": rest_api_id,
            "stageName": stage_name,
            "exportType": export_type,
            "parameters": parameters,
            "accepts": accepts,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    identity_pool_name: str,
    allow_unauthenticated_identities: bool,
    allow_classic_flow: bool = None,
    supported_login_providers: Dict = None,
    developer_provider_name: str = None,
    open_id_connect_provider_ar_ns: List = None,
    cognito_identity_providers: List = None,
    saml_provider_ar_ns: List = None,
    identity_pool_tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new identity pool. The identity pool is a store of user identity information that is specific to your AWS account. The keys for SupportedLoginProviders are as follows:   Facebook: graph.facebook.com    Google: accounts.google.com    Amazon: www.amazon.com    Twitter: api.twitter.com    Digits: www.digits.com    You must use AWS Developer credentials to call this API.

    Args:
        identity_pool_name(str): A string that you provide.
        allow_unauthenticated_identities(bool): TRUE if the identity pool supports unauthenticated logins.
        allow_classic_flow(bool, optional): Enables or disables the Basic (Classic) authentication flow. For more information, see Identity Pools (Federated Identities) Authentication Flow in the Amazon Cognito Developer Guide. Defaults to None.
        supported_login_providers(Dict, optional): Optional key:value pairs mapping provider names to provider app IDs. Defaults to None.
        developer_provider_name(str, optional): The "domain" by which Cognito will refer to your users. This name acts as a placeholder that allows your backend and the Cognito service to communicate about the developer provider. For the DeveloperProviderName, you can use letters as well as period (.), underscore (_), and dash (-). Once you have set a developer provider name, you cannot change it. Please take care in setting this parameter. Defaults to None.
        open_id_connect_provider_ar_ns(List, optional): The Amazon Resource Names (ARN) of the OpenID Connect providers. Defaults to None.
        cognito_identity_providers(List, optional): An array of Amazon Cognito user pools and their client IDs. Defaults to None.
        saml_provider_ar_ns(List, optional): An array of Amazon Resource Names (ARNs) of the SAML provider for your identity pool. Defaults to None.
        identity_pool_tags(Dict, optional): Tags to assign to the identity pool. A tag is a label that you can apply to identity pools to categorize and manage them in different ways, such as by purpose, owner, environment, or other criteria. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_identity.identity.pool.init.create(
                ctx, identity_pool_name=value, allow_unauthenticated_identities=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_identity.identity.pool.init.create identity_pool_name=value, allow_unauthenticated_identities=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-identity",
        operation="create_identity_pool",
        op_kwargs={
            "IdentityPoolName": identity_pool_name,
            "AllowUnauthenticatedIdentities": allow_unauthenticated_identities,
            "AllowClassicFlow": allow_classic_flow,
            "SupportedLoginProviders": supported_login_providers,
            "DeveloperProviderName": developer_provider_name,
            "OpenIdConnectProviderARNs": open_id_connect_provider_ar_ns,
            "CognitoIdentityProviders": cognito_identity_providers,
            "SamlProviderARNs": saml_provider_ar_ns,
            "IdentityPoolTags": identity_pool_tags,
        },
    )


async def delete(hub, ctx, identity_pool_id: str) -> None:
    r"""
    **Autogenerated function**

    Deletes an identity pool. Once a pool is deleted, users will not be able to authenticate with the pool. You must use AWS Developer credentials to call this API.

    Args:
        identity_pool_id(str): An identity pool ID in the format REGION:GUID.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_identity.identity.pool.init.delete(
                ctx, identity_pool_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_identity.identity.pool.init.delete identity_pool_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-identity",
        operation="delete_identity_pool",
        op_kwargs={"IdentityPoolId": identity_pool_id},
    )


async def describe(hub, ctx, identity_pool_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets details about a particular identity pool, including the pool name, ID description, creation date, and current number of users. You must use AWS Developer credentials to call this API.

    Args:
        identity_pool_id(str): An identity pool ID in the format REGION:GUID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_identity.identity.pool.init.describe(
                ctx, identity_pool_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_identity.identity.pool.init.describe identity_pool_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-identity",
        operation="describe_identity_pool",
        op_kwargs={"IdentityPoolId": identity_pool_id},
    )


async def list_all(hub, ctx, max_results: int, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists all of the Cognito identity pools registered for your account. You must use AWS Developer credentials to call this API.

    Args:
        max_results(int): The maximum number of identities to return.
        next_token(str, optional): A pagination token. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_identity.identity.pool.init.list_all(
                ctx, max_results=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_identity.identity.pool.init.list_all max_results=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-identity",
        operation="list_identity_pools",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )


async def update(
    hub,
    ctx,
    identity_pool_id: str,
    identity_pool_name: str,
    allow_unauthenticated_identities: bool,
    allow_classic_flow: bool = None,
    supported_login_providers: Dict = None,
    developer_provider_name: str = None,
    open_id_connect_provider_ar_ns: List = None,
    cognito_identity_providers: List = None,
    saml_provider_ar_ns: List = None,
    identity_pool_tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates an identity pool. You must use AWS Developer credentials to call this API.

    Args:
        identity_pool_id(str): An identity pool ID in the format REGION:GUID.
        identity_pool_name(str): A string that you provide.
        allow_unauthenticated_identities(bool): TRUE if the identity pool supports unauthenticated logins.
        allow_classic_flow(bool, optional): Enables or disables the Basic (Classic) authentication flow. For more information, see Identity Pools (Federated Identities) Authentication Flow in the Amazon Cognito Developer Guide. Defaults to None.
        supported_login_providers(Dict, optional): Optional key:value pairs mapping provider names to provider app IDs. Defaults to None.
        developer_provider_name(str, optional): The "domain" by which Cognito will refer to your users. Defaults to None.
        open_id_connect_provider_ar_ns(List, optional): The ARNs of the OpenID Connect providers. Defaults to None.
        cognito_identity_providers(List, optional): A list representing an Amazon Cognito user pool and its client ID. Defaults to None.
        saml_provider_ar_ns(List, optional): An array of Amazon Resource Names (ARNs) of the SAML provider for your identity pool. Defaults to None.
        identity_pool_tags(Dict, optional): The tags that are assigned to the identity pool. A tag is a label that you can apply to identity pools to categorize and manage them in different ways, such as by purpose, owner, environment, or other criteria. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_identity.identity.pool.init.update(
                ctx,
                identity_pool_id=value,
                identity_pool_name=value,
                allow_unauthenticated_identities=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_identity.identity.pool.init.update identity_pool_id=value, identity_pool_name=value, allow_unauthenticated_identities=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-identity",
        operation="update_identity_pool",
        op_kwargs={
            "IdentityPoolId": identity_pool_id,
            "IdentityPoolName": identity_pool_name,
            "AllowUnauthenticatedIdentities": allow_unauthenticated_identities,
            "AllowClassicFlow": allow_classic_flow,
            "SupportedLoginProviders": supported_login_providers,
            "DeveloperProviderName": developer_provider_name,
            "OpenIdConnectProviderARNs": open_id_connect_provider_ar_ns,
            "CognitoIdentityProviders": cognito_identity_providers,
            "SamlProviderARNs": saml_provider_ar_ns,
            "IdentityPoolTags": identity_pool_tags,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def start(hub, ctx, target_check_names: List) -> Dict:
    r"""
    **Autogenerated function**

    Starts an on-demand Device Defender audit.

    Args:
        target_check_names(List): Which checks are performed during the audit. The checks you specify must be enabled for your account or an exception occurs. Use DescribeAccountAuditConfiguration to see the list of all checks, including those that are enabled or UpdateAccountAuditConfiguration to select which checks are enabled.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.on_demand_audit_task.start(ctx, target_check_names=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.on_demand_audit_task.start target_check_names=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="start_on_demand_audit_task",
        op_kwargs={"targetCheckNames": target_check_names},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the current status and configuration settings for an Amazon Macie account.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.macie2.macie.session.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.macie2.macie.session.get
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="macie2", operation="get_macie_session", op_kwargs={}
    )


async def update(
    hub, ctx, finding_publishing_frequency: str = None, status: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Suspends or re-enables an Amazon Macie account, or updates the configuration settings for a Macie account.

    Args:
        finding_publishing_frequency(str, optional): Specifies how often to publish updates to policy findings for the account. This includes publishing updates to Security Hub and Amazon EventBridge (formerly called Amazon CloudWatch Events). Defaults to None.
        status(str, optional): Specifies a new status for the account. Valid values are: ENABLED, resume all Amazon Macie activities for the account; and, PAUSED, suspend all Macie activities for the account. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.macie2.macie.session.update(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.macie2.macie.session.update
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="macie2",
        operation="update_macie_session",
        op_kwargs={
            "findingPublishingFrequency": finding_publishing_frequency,
            "status": status,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def add(
    hub, ctx, application_name: str, current_application_version_id: int, input_: Dict
) -> Dict:
    r"""
    **Autogenerated function**

     This documentation is for version 1 of the Amazon Kinesis Data Analytics API, which only supports SQL applications. Version 2 of the API supports SQL and Java applications. For more information about version 2, see Amazon Kinesis Data Analytics API V2 Documentation.   Adds a streaming source to your Amazon Kinesis application. For conceptual information, see Configuring Application Input.  You can add a streaming source either when you create an application or you can use this operation to add a streaming source after you create an application. For more information, see CreateApplication. Any configuration update, including adding a streaming source using this operation, results in a new version of the application. You can use the DescribeApplication operation to find the current application version.  This operation requires permissions to perform the kinesisanalytics:AddApplicationInput action.

    Args:
        application_name(str): Name of your existing Amazon Kinesis Analytics application to which you want to add the streaming source.
        current_application_version_id(int): Current version of your Amazon Kinesis Analytics application. You can use the DescribeApplication operation to find the current application version.
        input_(Dict): The Input to add.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesisanalytic.application.input_.init.add(
                ctx, application_name=value, current_application_version_id=value, input_=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesisanalytic.application.input_.init.add application_name=value, current_application_version_id=value, input_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesisanalytics",
        operation="add_application_input",
        op_kwargs={
            "ApplicationName": application_name,
            "CurrentApplicationVersionId": current_application_version_id,
            "Input": input_,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def start(hub, ctx, detector_id: str, account_ids: List) -> Dict:
    r"""
    **Autogenerated function**

    Turns on GuardDuty monitoring of the specified member accounts. Use this operation to restart monitoring of accounts that you stopped monitoring with the StopMonitoringMembers operation.

    Args:
        detector_id(str): The unique ID of the detector of the GuardDuty administrator account associated with the member accounts to monitor.
        account_ids(List): A list of account IDs of the GuardDuty member accounts to start monitoring.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.guardduty.monitoring_member.start(
                ctx, detector_id=value, account_ids=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.guardduty.monitoring_member.start detector_id=value, account_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="guardduty",
        operation="start_monitoring_members",
        op_kwargs={"DetectorId": detector_id, "AccountIds": account_ids},
    )


async def stop(hub, ctx, detector_id: str, account_ids: List) -> Dict:
    r"""
    **Autogenerated function**

    Stops GuardDuty monitoring for the specified member accounts. Use the StartMonitoringMembers operation to restart monitoring for those accounts.

    Args:
        detector_id(str): The unique ID of the detector associated with the GuardDuty administrator account that is monitoring member accounts.
        account_ids(List): A list of account IDs for the member accounts to stop monitoring.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.guardduty.monitoring_member.stop(
                ctx, detector_id=value, account_ids=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.guardduty.monitoring_member.stop detector_id=value, account_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="guardduty",
        operation="stop_monitoring_members",
        op_kwargs={"DetectorId": detector_id, "AccountIds": account_ids},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, delete_scheduled_audits: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Restores the default settings for Device Defender audits for this account. Any configuration data you entered is deleted and all audit checks are reset to disabled.

    Args:
        delete_scheduled_audits(bool, optional): If true, all scheduled audits are deleted. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.account_audit_configuration.delete(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.account_audit_configuration.delete
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="delete_account_audit_configuration",
        op_kwargs={"deleteScheduledAudits": delete_scheduled_audits},
    )


async def describe(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about the Device Defender audit settings for this account. Settings include how audit notifications are sent and which audit checks are enabled or disabled.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.account_audit_configuration.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.account_audit_configuration.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="describe_account_audit_configuration",
        op_kwargs={},
    )


async def update(
    hub,
    ctx,
    role_arn: str = None,
    audit_notification_target_configurations: Dict = None,
    audit_check_configurations: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Configures or reconfigures the Device Defender audit settings for this account. Settings include how audit notifications are sent and which audit checks are enabled or disabled.

    Args:
        role_arn(str, optional): The Amazon Resource Name (ARN) of the role that grants permission to AWS IoT to access information about your devices, policies, certificates, and other items as required when performing an audit. Defaults to None.
        audit_notification_target_configurations(Dict, optional): Information about the targets to which audit notifications are sent. Defaults to None.
        audit_check_configurations(Dict, optional): Specifies which audit checks are enabled and disabled for this account. Use DescribeAccountAuditConfiguration to see the list of all checks, including those that are currently enabled. Some data collection might start immediately when certain checks are enabled. When a check is disabled, any data collected so far in relation to the check is deleted. You cannot disable a check if it's used by any scheduled audit. You must first delete the check from the scheduled audit or delete the scheduled audit itself. On the first call to UpdateAccountAuditConfiguration, this parameter is required and must specify at least one enabled check. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.account_audit_configuration.update(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.account_audit_configuration.update
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="update_account_audit_configuration",
        op_kwargs={
            "roleArn": role_arn,
            "auditNotificationTargetConfigurations": audit_notification_target_configurations,
            "auditCheckConfigurations": audit_check_configurations,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def send(
    hub,
    ctx,
    name: str,
    preview: bool = None,
    recipe_step: Dict = None,
    step_index: int = None,
    client_session_id: str = None,
    view_frame: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Performs a recipe step within an interactive DataBrew session that's currently open.

    Args:
        preview(bool, optional): If true, the result of the recipe step will be returned, but not applied. Defaults to None.
        name(str): The name of the project to apply the action to.
        recipe_step(Dict, optional): Represents a single step from a DataBrew recipe to be performed. Defaults to None.
        step_index(int, optional): The index from which to preview a step. This index is used to preview the result of steps that have already been applied, so that the resulting view frame is from earlier in the view frame stack. Defaults to None.
        client_session_id(str, optional): A unique identifier for an interactive session that's currently open and ready for work. The action will be performed on this session. Defaults to None.
        view_frame(Dict, optional): Represents the data being transformed during an action. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.databrew.project.session.action.send(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.databrew.project.session.action.send name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="databrew",
        operation="send_project_session_action",
        op_kwargs={
            "Preview": preview,
            "Name": name,
            "RecipeStep": recipe_step,
            "StepIndex": step_index,
            "ClientSessionId": client_session_id,
            "ViewFrame": view_frame,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(hub, ctx, organization_conformance_pack_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified organization conformance pack and all of the config rules and remediation actions from all member accounts in that organization.   Only a master account or a delegated administrator account can delete an organization conformance pack. When calling this API with a delegated administrator, you must ensure AWS Organizations ListDelegatedAdministrator permissions are added. AWS Config sets the state of a conformance pack to DELETE_IN_PROGRESS until the deletion is complete. You cannot update a conformance pack while it is in this state.

    Args:
        organization_conformance_pack_name(str): The name of organization conformance pack that you want to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.config.organization.conformance_pack.init.delete(
                ctx, organization_conformance_pack_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.config.organization.conformance_pack.init.delete organization_conformance_pack_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="config",
        operation="delete_organization_conformance_pack",
        op_kwargs={
            "OrganizationConformancePackName": organization_conformance_pack_name
        },
    )


async def describe_all(
    hub,
    ctx,
    organization_conformance_pack_names: List = None,
    limit: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of organization conformance packs.   When you specify the limit and the next token, you receive a paginated response.  Limit and next token are not applicable if you specify organization conformance packs names. They are only applicable, when you request all the organization conformance packs.

    Args:
        organization_conformance_pack_names(List, optional): The name that you assign to an organization conformance pack. Defaults to None.
        limit(int, optional): The maximum number of organization config packs returned on each page. If you do no specify a number, AWS Config uses the default. The default is 100. Defaults to None.
        next_token(str, optional): The nextToken string returned on a previous page that you use to get the next page of results in a paginated response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.config.organization.conformance_pack.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.config.organization.conformance_pack.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="config",
        operation="describe_organization_conformance_packs",
        op_kwargs={
            "OrganizationConformancePackNames": organization_conformance_pack_names,
            "Limit": limit,
            "NextToken": next_token,
        },
    )


async def put(
    hub,
    ctx,
    organization_conformance_pack_name: str,
    template_s3_uri: str = None,
    template_body: str = None,
    delivery_s3_bucket: str = None,
    delivery_s3_key_prefix: str = None,
    conformance_pack_input_parameters: List = None,
    excluded_accounts: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Deploys conformance packs across member accounts in an AWS Organization. Only a master account and a delegated administrator can call this API. When calling this API with a delegated administrator, you must ensure AWS Organizations ListDelegatedAdministrator permissions are added. This API enables organization service access for config-multiaccountsetup.amazonaws.com through the EnableAWSServiceAccess action and creates a service linked role AWSServiceRoleForConfigMultiAccountSetup in the master or delegated administrator account of your organization. The service linked role is created only when the role does not exist in the caller account. To use this API with delegated administrator, register a delegated administrator by calling AWS Organization register-delegate-admin for config-multiaccountsetup.amazonaws.com.  Prerequisite: Ensure you call EnableAllFeatures API to enable all features in an organization. You must specify either the TemplateS3Uri or the TemplateBody parameter, but not both. If you provide both AWS Config uses the TemplateS3Uri parameter and ignores the TemplateBody parameter. AWS Config sets the state of a conformance pack to CREATE_IN_PROGRESS and UPDATE_IN_PROGRESS until the conformance pack is created or updated. You cannot update a conformance pack while it is in this state. You can create 50 conformance packs with 25 AWS Config rules in each pack and 3 delegated administrator per organization.

    Args:
        organization_conformance_pack_name(str): Name of the organization conformance pack you want to create.
        template_s3_uri(str, optional): Location of file containing the template body. The uri must point to the conformance pack template (max size: 300 KB).  You must have access to read Amazon S3 bucket. . Defaults to None.
        template_body(str, optional): A string containing full conformance pack template body. Structure containing the template body with a minimum length of 1 byte and a maximum length of 51,200 bytes. Defaults to None.
        delivery_s3_bucket(str, optional): Amazon S3 bucket where AWS Config stores conformance pack templates.  This field is optional. If used, it must be prefixed with awsconfigconforms. . Defaults to None.
        delivery_s3_key_prefix(str, optional): The prefix for the Amazon S3 bucket.  This field is optional. . Defaults to None.
        conformance_pack_input_parameters(List, optional): A list of ConformancePackInputParameter objects. Defaults to None.
        excluded_accounts(List, optional): A list of AWS accounts to be excluded from an organization conformance pack while deploying a conformance pack. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.config.organization.conformance_pack.init.put(
                ctx, organization_conformance_pack_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.config.organization.conformance_pack.init.put organization_conformance_pack_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="config",
        operation="put_organization_conformance_pack",
        op_kwargs={
            "OrganizationConformancePackName": organization_conformance_pack_name,
            "TemplateS3Uri": template_s3_uri,
            "TemplateBody": template_body,
            "DeliveryS3Bucket": delivery_s3_bucket,
            "DeliveryS3KeyPrefix": delivery_s3_key_prefix,
            "ConformancePackInputParameters": conformance_pack_input_parameters,
            "ExcludedAccounts": excluded_accounts,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def add(
    hub,
    ctx,
    application_name: str,
    current_application_version_id: int,
    reference_data_source: Dict,
) -> Dict:
    r"""
    **Autogenerated function**

    Adds a reference data source to an existing SQL-based Kinesis Data Analytics application. Kinesis Data Analytics reads reference data (that is, an Amazon S3 object) and creates an in-application table within your application. In the request, you provide the source (S3 bucket name and object key name), name of the in-application table to create, and the necessary mapping information that describes how data in an Amazon S3 object maps to columns in the resulting in-application table.

    Args:
        application_name(str): The name of an existing application.
        current_application_version_id(int): The version of the application for which you are adding the reference data source. You can use the DescribeApplication operation to get the current application version. If the version specified is not the current version, the ConcurrentModificationException is returned.
        reference_data_source(Dict): The reference data source can be an object in your Amazon S3 bucket. Kinesis Data Analytics reads the object and copies the data into the in-application table that is created. You provide an S3 bucket, object key name, and the resulting in-application table that is created. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesisanalyticsv2.application.reference_data_source.add(
                ctx,
                application_name=value,
                current_application_version_id=value,
                reference_data_source=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesisanalyticsv2.application.reference_data_source.add application_name=value, current_application_version_id=value, reference_data_source=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesisanalyticsv2",
        operation="add_application_reference_data_source",
        op_kwargs={
            "ApplicationName": application_name,
            "CurrentApplicationVersionId": current_application_version_id,
            "ReferenceDataSource": reference_data_source,
        },
    )


async def delete(
    hub,
    ctx,
    application_name: str,
    current_application_version_id: int,
    reference_id: str,
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a reference data source configuration from the specified SQL-based Kinesis Data Analytics application's configuration. If the application is running, Kinesis Data Analytics immediately removes the in-application table that you created using the AddApplicationReferenceDataSource operation.

    Args:
        application_name(str): The name of an existing application.
        current_application_version_id(int): The current application version. You can use the DescribeApplication operation to get the current application version. If the version specified is not the current version, the ConcurrentModificationException is returned.
        reference_id(str): The ID of the reference data source. When you add a reference data source to your application using the AddApplicationReferenceDataSource, Kinesis Data Analytics assigns an ID. You can use the DescribeApplication operation to get the reference ID. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesisanalyticsv2.application.reference_data_source.delete(
                ctx,
                application_name=value,
                current_application_version_id=value,
                reference_id=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesisanalyticsv2.application.reference_data_source.delete application_name=value, current_application_version_id=value, reference_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesisanalyticsv2",
        operation="delete_application_reference_data_source",
        op_kwargs={
            "ApplicationName": application_name,
            "CurrentApplicationVersionId": current_application_version_id,
            "ReferenceId": reference_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub,
    ctx,
    start_time: str,
    end_time: str,
    group_name: str = None,
    group_arn: str = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a document that describes services that process incoming requests, and downstream services that they call as a result. Root services process incoming requests and make calls to downstream services. Root services are applications that use the AWS X-Ray SDK. Downstream services can be other applications, AWS resources, HTTP web APIs, or SQL databases.

    Args:
        start_time(str): The start of the time frame for which to generate a graph.
        end_time(str): The end of the timeframe for which to generate a graph.
        group_name(str, optional): The name of a group based on which you want to generate a graph. Defaults to None.
        group_arn(str, optional): The Amazon Resource Name (ARN) of a group based on which you want to generate a graph. Defaults to None.
        next_token(str, optional): Pagination token. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.xray.service_graph.get(ctx, start_time=value, end_time=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.xray.service_graph.get start_time=value, end_time=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="xray",
        operation="get_service_graph",
        op_kwargs={
            "StartTime": start_time,
            "EndTime": end_time,
            "GroupName": group_name,
            "GroupARN": group_arn,
            "NextToken": next_token,
        },
    )
